/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

import { mount, shallow } from 'enzyme';
import { clone } from 'lodash/fp';
import React from 'react';
import { FlowDirection, FlowTarget } from '../../../../common/search_strategy';

import { FlowTargetSelect } from './flow_target_select';

describe('FlowTargetSelect Component', () => {
  const TestFlowTargetId = 'TestFlowTargetId';

  const mockProps = {
    id: TestFlowTargetId,
    selectedDirection: FlowDirection.uniDirectional,
    isLoading: false,
    selectedTarget: FlowTarget.source,
    updateFlowTargetAction: jest.fn(),
  };

  describe('rendering', () => {
    test('it renders the FlowTargetSelect', () => {
      const wrapper = shallow(<FlowTargetSelect {...mockProps} />);

      expect(wrapper).toMatchSnapshot();
    });
  });

  test('selecting destination from the type drop down', () => {
    const wrapper = mount(<FlowTargetSelect {...mockProps} />);

    wrapper.find('button').first().simulate('click');

    wrapper.update();

    wrapper
      .find(`button#${TestFlowTargetId}-select-flow-target-destination`)
      .first()
      .simulate('click');

    wrapper.update();

    expect(mockProps.updateFlowTargetAction.mock.calls[0][0]).toEqual('destination');
  });

  test('when selectedDirection=unidirectional only source/destination are options', () => {
    const wrapper = mount(<FlowTargetSelect {...mockProps} />);

    wrapper.find('button').first().simulate('click');

    wrapper.update();

    expect(
      wrapper.find(`button#${TestFlowTargetId}-select-flow-target-source`).exists()
    ).toBeTruthy();
    expect(
      wrapper.find(`button#${TestFlowTargetId}-select-flow-target-destination`).exists()
    ).toBeTruthy();
    expect(
      wrapper.find(`button#${TestFlowTargetId}-select-flow-target-client`).exists()
    ).toBeFalsy();
    expect(
      wrapper.find(`button#${TestFlowTargetId}-select-flow-target-server`).exists()
    ).toBeFalsy();
  });

  test('when selectedDirection=bidirectional source/destination/client/server are options', () => {
    const bidirectionalMock = clone(mockProps);
    bidirectionalMock.selectedDirection = FlowDirection.biDirectional;

    const wrapper = mount(<FlowTargetSelect {...bidirectionalMock} />);

    wrapper.find('button').first().simulate('click');

    wrapper.update();

    expect(
      wrapper.find(`button#${TestFlowTargetId}-select-flow-target-source`).exists()
    ).toBeTruthy();
    expect(
      wrapper.find(`button#${TestFlowTargetId}-select-flow-target-destination`).exists()
    ).toBeTruthy();
    expect(
      wrapper.find(`button#${TestFlowTargetId}-select-flow-target-client`).exists()
    ).toBeTruthy();
    expect(
      wrapper.find(`button#${TestFlowTargetId}-select-flow-target-server`).exists()
    ).toBeTruthy();
  });
});
