/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

import type { IEsSearchResponse } from '../../../../../../../../../src/plugins/data/common';

import { MatrixHistogramStrategyResponse } from '../../../../../../common/search_strategy';

export const mockAlertsSearchStrategyResponse: IEsSearchResponse<unknown> = {
  isPartial: false,
  isRunning: false,
  rawResponse: {
    took: 11,
    timed_out: false,
    _shards: { total: 21, successful: 21, skipped: 0, failed: 0 },
    hits: { total: 0, max_score: 0, hits: [] },
    aggregations: {
      alertsGroup: { doc_count_error_upper_bound: 0, sum_other_doc_count: 0, buckets: [] },
    },
  },
  total: 21,
  loaded: 21,
};

export const formattedAlertsSearchStrategyResponse: MatrixHistogramStrategyResponse = {
  ...mockAlertsSearchStrategyResponse,
  inspect: {
    dsl: [
      JSON.stringify(
        {
          index: [
            'apm-*-transaction*',
            'traces-apm*',
            'auditbeat-*',
            'endgame-*',
            'filebeat-*',
            'logs-*',
            'packetbeat-*',
            'winlogbeat-*',
          ],
          allow_no_indices: true,
          ignore_unavailable: true,
          track_total_hits: true,
          body: {
            aggregations: {
              alertsGroup: {
                terms: {
                  field: 'event.module',
                  missing: 'All others',
                  order: { _count: 'desc' },
                  size: 10,
                },
                aggs: {
                  alerts: {
                    date_histogram: {
                      field: '@timestamp',
                      fixed_interval: '2700000ms',
                      min_doc_count: 0,
                      extended_bounds: { min: 1599574984482, max: 1599661384482 },
                    },
                  },
                },
              },
            },
            query: {
              bool: {
                filter: [
                  {
                    bool: {
                      must: [],
                      filter: [
                        { match_all: {} },
                        {
                          bool: {
                            filter: [
                              {
                                bool: {
                                  should: [{ exists: { field: 'host.name' } }],
                                  minimum_should_match: 1,
                                },
                              },
                            ],
                          },
                        },
                      ],
                      should: [],
                      must_not: [],
                    },
                  },
                  {
                    bool: {
                      filter: [
                        {
                          bool: {
                            should: [{ match: { 'event.kind': 'alert' } }],
                            minimum_should_match: 1,
                          },
                        },
                      ],
                    },
                  },
                  {
                    range: {
                      '@timestamp': {
                        gte: '2020-09-08T14:23:04.482Z',
                        lte: '2020-09-09T14:23:04.482Z',
                        format: 'strict_date_optional_time',
                      },
                    },
                  },
                ],
              },
            },
            size: 0,
          },
        },
        null,
        2
      ),
    ],
  },
  matrixHistogramData: [],
  totalCount: 0,
};

export const expectedDsl = {
  allow_no_indices: true,
  track_total_hits: false,
  body: {
    aggregations: {
      host_count: { cardinality: { field: 'host.name' } },
      host_data: {
        aggs: {
          lastSeen: { max: { field: '@timestamp' } },
          os: {
            top_hits: {
              _source: { includes: ['host.os.*'] },
              size: 1,
              sort: [{ '@timestamp': { order: 'desc' } }],
            },
          },
        },
        terms: { field: 'host.name', order: { lastSeen: 'desc' }, size: 10 },
      },
    },
    query: {
      bool: {
        filter: [
          { bool: { filter: [{ match_all: {} }], must: [], must_not: [], should: [] } },
          {
            range: {
              '@timestamp': {
                format: 'strict_date_optional_time',
                gte: '2020-09-03T09:15:21.415Z',
                lte: '2020-09-04T09:15:21.415Z',
              },
            },
          },
        ],
      },
    },
    size: 0,
  },
  ignore_unavailable: true,
  index: [
    'apm-*-transaction*',
    'traces-apm*',
    'auditbeat-*',
    'endgame-*',
    'filebeat-*',
    'logs-*',
    'packetbeat-*',
    'winlogbeat-*',
  ],
};

export const mockAnomaliesSearchStrategyResponse: IEsSearchResponse<unknown> = {
  isPartial: false,
  isRunning: false,
  rawResponse: {
    took: 9,
    timed_out: false,
    _shards: { total: 21, successful: 21, skipped: 0, failed: 0 },
    hits: { total: 0, max_score: 0, hits: [] },
    aggregations: {
      anomalyActionGroup: { doc_count_error_upper_bound: 0, sum_other_doc_count: 0, buckets: [] },
    },
  },
  total: 21,
  loaded: 21,
};

export const formattedAnomaliesSearchStrategyResponse: MatrixHistogramStrategyResponse = {
  ...mockAnomaliesSearchStrategyResponse,
  inspect: {
    dsl: [
      JSON.stringify(
        {
          index: [
            'apm-*-transaction*',
            'traces-apm*',
            'auditbeat-*',
            'endgame-*',
            'filebeat-*',
            'logs-*',
            'packetbeat-*',
            'winlogbeat-*',
          ],
          allow_no_indices: true,
          ignore_unavailable: true,
          track_total_hits: true,
          body: {
            aggs: {
              anomalyActionGroup: {
                terms: { field: 'job_id', order: { _count: 'desc' }, size: 10 },
                aggs: {
                  anomalies: {
                    date_histogram: {
                      field: 'timestamp',
                      fixed_interval: '2700000ms',
                      min_doc_count: 0,
                      extended_bounds: { min: 1599578075566, max: 1599664475566 },
                    },
                  },
                },
              },
            },
            query: {
              bool: {
                filter: [
                  {
                    bool: {
                      must: [],
                      filter: [
                        { match_all: {} },
                        { bool: { should: [], minimum_should_match: 1 } },
                        { match_phrase: { result_type: 'record' } },
                        null,
                        { range: { record_score: { gte: 50 } } },
                      ],
                      should: [
                        { exists: { field: 'source.ip' } },
                        { exists: { field: 'destination.ip' } },
                      ],
                      must_not: [],
                      minimum_should_match: 1,
                    },
                  },
                  {
                    range: {
                      timestamp: {
                        gte: '2020-09-08T15:14:35.566Z',
                        lte: '2020-09-09T15:14:35.566Z',
                        format: 'strict_date_optional_time',
                      },
                    },
                  },
                ],
              },
            },
            size: 0,
          },
        },
        null,
        2
      ),
    ],
  },
  matrixHistogramData: [],
  totalCount: 0,
};

export const mockAuthenticationsSearchStrategyResponse: IEsSearchResponse<unknown> = {
  isPartial: false,
  isRunning: false,
  rawResponse: {
    took: 6,
    timed_out: false,
    _shards: { total: 21, successful: 21, skipped: 0, failed: 0 },
    hits: { total: 0, max_score: 0, hits: [] },
    aggregations: {
      eventActionGroup: {
        doc_count_error_upper_bound: 0,
        sum_other_doc_count: 0,
        buckets: [
          {
            key: 'failure',
            doc_count: 379,
            events: {
              buckets: [
                { key_as_string: '2020-09-08T15:00:00.000Z', key: 1599577200000, doc_count: 1 },
                { key_as_string: '2020-09-08T15:45:00.000Z', key: 1599579900000, doc_count: 4 },
                { key_as_string: '2020-09-08T16:30:00.000Z', key: 1599582600000, doc_count: 34 },
                { key_as_string: '2020-09-08T17:15:00.000Z', key: 1599585300000, doc_count: 1 },
                { key_as_string: '2020-09-08T18:00:00.000Z', key: 1599588000000, doc_count: 3 },
                { key_as_string: '2020-09-08T18:45:00.000Z', key: 1599590700000, doc_count: 20 },
                { key_as_string: '2020-09-08T19:30:00.000Z', key: 1599593400000, doc_count: 24 },
                { key_as_string: '2020-09-08T20:15:00.000Z', key: 1599596100000, doc_count: 37 },
                { key_as_string: '2020-09-08T21:00:00.000Z', key: 1599598800000, doc_count: 4 },
                { key_as_string: '2020-09-08T21:45:00.000Z', key: 1599601500000, doc_count: 22 },
                { key_as_string: '2020-09-08T22:30:00.000Z', key: 1599604200000, doc_count: 3 },
                { key_as_string: '2020-09-08T23:15:00.000Z', key: 1599606900000, doc_count: 0 },
                { key_as_string: '2020-09-09T00:00:00.000Z', key: 1599609600000, doc_count: 2 },
                { key_as_string: '2020-09-09T00:45:00.000Z', key: 1599612300000, doc_count: 21 },
                { key_as_string: '2020-09-09T01:30:00.000Z', key: 1599615000000, doc_count: 28 },
                { key_as_string: '2020-09-09T02:15:00.000Z', key: 1599617700000, doc_count: 30 },
                { key_as_string: '2020-09-09T03:00:00.000Z', key: 1599620400000, doc_count: 19 },
                { key_as_string: '2020-09-09T03:45:00.000Z', key: 1599623100000, doc_count: 4 },
                { key_as_string: '2020-09-09T04:30:00.000Z', key: 1599625800000, doc_count: 1 },
                { key_as_string: '2020-09-09T05:15:00.000Z', key: 1599628500000, doc_count: 6 },
                { key_as_string: '2020-09-09T06:00:00.000Z', key: 1599631200000, doc_count: 18 },
                { key_as_string: '2020-09-09T06:45:00.000Z', key: 1599633900000, doc_count: 5 },
                { key_as_string: '2020-09-09T07:30:00.000Z', key: 1599636600000, doc_count: 23 },
                { key_as_string: '2020-09-09T08:15:00.000Z', key: 1599639300000, doc_count: 15 },
                { key_as_string: '2020-09-09T09:00:00.000Z', key: 1599642000000, doc_count: 2 },
                { key_as_string: '2020-09-09T09:45:00.000Z', key: 1599644700000, doc_count: 0 },
                { key_as_string: '2020-09-09T10:30:00.000Z', key: 1599647400000, doc_count: 5 },
                { key_as_string: '2020-09-09T11:15:00.000Z', key: 1599650100000, doc_count: 2 },
                { key_as_string: '2020-09-09T12:00:00.000Z', key: 1599652800000, doc_count: 4 },
                { key_as_string: '2020-09-09T12:45:00.000Z', key: 1599655500000, doc_count: 6 },
                { key_as_string: '2020-09-09T13:30:00.000Z', key: 1599658200000, doc_count: 11 },
                { key_as_string: '2020-09-09T14:15:00.000Z', key: 1599660900000, doc_count: 0 },
                { key_as_string: '2020-09-09T15:00:00.000Z', key: 1599663600000, doc_count: 24 },
              ],
            },
          },
          {
            key: 'success',
            doc_count: 191,
            events: {
              buckets: [
                { key_as_string: '2020-09-08T15:00:00.000Z', key: 1599577200000, doc_count: 2 },
                { key_as_string: '2020-09-08T15:45:00.000Z', key: 1599579900000, doc_count: 5 },
                { key_as_string: '2020-09-08T16:30:00.000Z', key: 1599582600000, doc_count: 5 },
                { key_as_string: '2020-09-08T17:15:00.000Z', key: 1599585300000, doc_count: 2 },
                { key_as_string: '2020-09-08T18:00:00.000Z', key: 1599588000000, doc_count: 4 },
                { key_as_string: '2020-09-08T18:45:00.000Z', key: 1599590700000, doc_count: 6 },
                { key_as_string: '2020-09-08T19:30:00.000Z', key: 1599593400000, doc_count: 4 },
                { key_as_string: '2020-09-08T20:15:00.000Z', key: 1599596100000, doc_count: 13 },
                { key_as_string: '2020-09-08T21:00:00.000Z', key: 1599598800000, doc_count: 6 },
                { key_as_string: '2020-09-08T21:45:00.000Z', key: 1599601500000, doc_count: 3 },
                { key_as_string: '2020-09-08T22:30:00.000Z', key: 1599604200000, doc_count: 1 },
                { key_as_string: '2020-09-08T23:15:00.000Z', key: 1599606900000, doc_count: 9 },
                { key_as_string: '2020-09-09T00:00:00.000Z', key: 1599609600000, doc_count: 5 },
                { key_as_string: '2020-09-09T00:45:00.000Z', key: 1599612300000, doc_count: 6 },
                { key_as_string: '2020-09-09T01:30:00.000Z', key: 1599615000000, doc_count: 8 },
                { key_as_string: '2020-09-09T02:15:00.000Z', key: 1599617700000, doc_count: 2 },
                { key_as_string: '2020-09-09T03:00:00.000Z', key: 1599620400000, doc_count: 9 },
                { key_as_string: '2020-09-09T03:45:00.000Z', key: 1599623100000, doc_count: 2 },
                { key_as_string: '2020-09-09T04:30:00.000Z', key: 1599625800000, doc_count: 5 },
                { key_as_string: '2020-09-09T05:15:00.000Z', key: 1599628500000, doc_count: 2 },
                { key_as_string: '2020-09-09T06:00:00.000Z', key: 1599631200000, doc_count: 14 },
                { key_as_string: '2020-09-09T06:45:00.000Z', key: 1599633900000, doc_count: 7 },
                { key_as_string: '2020-09-09T07:30:00.000Z', key: 1599636600000, doc_count: 13 },
                { key_as_string: '2020-09-09T08:15:00.000Z', key: 1599639300000, doc_count: 10 },
                { key_as_string: '2020-09-09T09:00:00.000Z', key: 1599642000000, doc_count: 5 },
                { key_as_string: '2020-09-09T09:45:00.000Z', key: 1599644700000, doc_count: 2 },
                { key_as_string: '2020-09-09T10:30:00.000Z', key: 1599647400000, doc_count: 6 },
                { key_as_string: '2020-09-09T11:15:00.000Z', key: 1599650100000, doc_count: 7 },
                { key_as_string: '2020-09-09T12:00:00.000Z', key: 1599652800000, doc_count: 5 },
                { key_as_string: '2020-09-09T12:45:00.000Z', key: 1599655500000, doc_count: 6 },
                { key_as_string: '2020-09-09T13:30:00.000Z', key: 1599658200000, doc_count: 5 },
                { key_as_string: '2020-09-09T14:15:00.000Z', key: 1599660900000, doc_count: 10 },
                { key_as_string: '2020-09-09T15:00:00.000Z', key: 1599663600000, doc_count: 2 },
              ],
            },
          },
        ],
      },
    },
  },
  total: 21,
  loaded: 21,
};

export const formattedAuthenticationsSearchStrategyResponse: MatrixHistogramStrategyResponse = {
  ...mockAuthenticationsSearchStrategyResponse,
  inspect: {
    dsl: [
      JSON.stringify(
        {
          index: [
            'apm-*-transaction*',
            'traces-apm*',
            'auditbeat-*',
            'endgame-*',
            'filebeat-*',
            'logs-*',
            'packetbeat-*',
            'winlogbeat-*',
          ],
          allow_no_indices: true,
          ignore_unavailable: true,
          track_total_hits: true,
          body: {
            aggregations: {
              eventActionGroup: {
                terms: {
                  field: 'event.outcome',
                  include: ['success', 'failure'],
                  order: { _count: 'desc' },
                  size: 2,
                },
                aggs: {
                  events: {
                    date_histogram: {
                      field: '@timestamp',
                      fixed_interval: '2700000ms',
                      min_doc_count: 0,
                      extended_bounds: { min: 1599578520325, max: 1599664920325 },
                    },
                  },
                },
              },
            },
            query: {
              bool: {
                filter: [
                  { bool: { must: [], filter: [{ match_all: {} }], should: [], must_not: [] } },
                  { bool: { must: [{ term: { 'event.category': 'authentication' } }] } },
                  {
                    range: {
                      '@timestamp': {
                        gte: '2020-09-08T15:22:00.325Z',
                        lte: '2020-09-09T15:22:00.325Z',
                        format: 'strict_date_optional_time',
                      },
                    },
                  },
                ],
              },
            },
            size: 0,
          },
        },
        null,
        2
      ),
    ],
  },
  matrixHistogramData: [
    { x: 1599577200000, y: 1, g: 'failure' },
    { x: 1599579900000, y: 4, g: 'failure' },
    { x: 1599582600000, y: 34, g: 'failure' },
    { x: 1599585300000, y: 1, g: 'failure' },
    { x: 1599588000000, y: 3, g: 'failure' },
    { x: 1599590700000, y: 20, g: 'failure' },
    { x: 1599593400000, y: 24, g: 'failure' },
    { x: 1599596100000, y: 37, g: 'failure' },
    { x: 1599598800000, y: 4, g: 'failure' },
    { x: 1599601500000, y: 22, g: 'failure' },
    { x: 1599604200000, y: 3, g: 'failure' },
    { x: 1599606900000, y: 0, g: 'failure' },
    { x: 1599609600000, y: 2, g: 'failure' },
    { x: 1599612300000, y: 21, g: 'failure' },
    { x: 1599615000000, y: 28, g: 'failure' },
    { x: 1599617700000, y: 30, g: 'failure' },
    { x: 1599620400000, y: 19, g: 'failure' },
    { x: 1599623100000, y: 4, g: 'failure' },
    { x: 1599625800000, y: 1, g: 'failure' },
    { x: 1599628500000, y: 6, g: 'failure' },
    { x: 1599631200000, y: 18, g: 'failure' },
    { x: 1599633900000, y: 5, g: 'failure' },
    { x: 1599636600000, y: 23, g: 'failure' },
    { x: 1599639300000, y: 15, g: 'failure' },
    { x: 1599642000000, y: 2, g: 'failure' },
    { x: 1599644700000, y: 0, g: 'failure' },
    { x: 1599647400000, y: 5, g: 'failure' },
    { x: 1599650100000, y: 2, g: 'failure' },
    { x: 1599652800000, y: 4, g: 'failure' },
    { x: 1599655500000, y: 6, g: 'failure' },
    { x: 1599658200000, y: 11, g: 'failure' },
    { x: 1599660900000, y: 0, g: 'failure' },
    { x: 1599663600000, y: 24, g: 'failure' },
    { x: 1599577200000, y: 2, g: 'success' },
    { x: 1599579900000, y: 5, g: 'success' },
    { x: 1599582600000, y: 5, g: 'success' },
    { x: 1599585300000, y: 2, g: 'success' },
    { x: 1599588000000, y: 4, g: 'success' },
    { x: 1599590700000, y: 6, g: 'success' },
    { x: 1599593400000, y: 4, g: 'success' },
    { x: 1599596100000, y: 13, g: 'success' },
    { x: 1599598800000, y: 6, g: 'success' },
    { x: 1599601500000, y: 3, g: 'success' },
    { x: 1599604200000, y: 1, g: 'success' },
    { x: 1599606900000, y: 9, g: 'success' },
    { x: 1599609600000, y: 5, g: 'success' },
    { x: 1599612300000, y: 6, g: 'success' },
    { x: 1599615000000, y: 8, g: 'success' },
    { x: 1599617700000, y: 2, g: 'success' },
    { x: 1599620400000, y: 9, g: 'success' },
    { x: 1599623100000, y: 2, g: 'success' },
    { x: 1599625800000, y: 5, g: 'success' },
    { x: 1599628500000, y: 2, g: 'success' },
    { x: 1599631200000, y: 14, g: 'success' },
    { x: 1599633900000, y: 7, g: 'success' },
    { x: 1599636600000, y: 13, g: 'success' },
    { x: 1599639300000, y: 10, g: 'success' },
    { x: 1599642000000, y: 5, g: 'success' },
    { x: 1599644700000, y: 2, g: 'success' },
    { x: 1599647400000, y: 6, g: 'success' },
    { x: 1599650100000, y: 7, g: 'success' },
    { x: 1599652800000, y: 5, g: 'success' },
    { x: 1599655500000, y: 6, g: 'success' },
    { x: 1599658200000, y: 5, g: 'success' },
    { x: 1599660900000, y: 10, g: 'success' },
    { x: 1599663600000, y: 2, g: 'success' },
  ],
  totalCount: 0,
};

export const mockEventsSearchStrategyResponse: IEsSearchResponse<unknown> = {
  isPartial: false,
  isRunning: false,
  rawResponse: {
    took: 198,
    timed_out: false,
    _shards: { total: 21, successful: 21, skipped: 0, failed: 0 },
    hits: { total: 0, max_score: 0, hits: [] },
    aggregations: {
      eventActionGroup: {
        doc_count_error_upper_bound: 3,
        sum_other_doc_count: 4090,
        buckets: [
          {
            key: 'All others',
            doc_count: 1556741,
            events: {
              buckets: [
                { key_as_string: '2020-09-08T15:45:00.000Z', key: 1599579900000, doc_count: 26124 },
                { key_as_string: '2020-09-08T16:30:00.000Z', key: 1599582600000, doc_count: 62910 },
                { key_as_string: '2020-09-08T17:15:00.000Z', key: 1599585300000, doc_count: 60326 },
                { key_as_string: '2020-09-08T18:00:00.000Z', key: 1599588000000, doc_count: 56144 },
                { key_as_string: '2020-09-08T18:45:00.000Z', key: 1599590700000, doc_count: 53614 },
                { key_as_string: '2020-09-08T19:30:00.000Z', key: 1599593400000, doc_count: 53228 },
                { key_as_string: '2020-09-08T20:15:00.000Z', key: 1599596100000, doc_count: 61195 },
                { key_as_string: '2020-09-08T21:00:00.000Z', key: 1599598800000, doc_count: 52082 },
                { key_as_string: '2020-09-08T21:45:00.000Z', key: 1599601500000, doc_count: 52697 },
                { key_as_string: '2020-09-08T22:30:00.000Z', key: 1599604200000, doc_count: 41094 },
                { key_as_string: '2020-09-08T23:15:00.000Z', key: 1599606900000, doc_count: 50164 },
                { key_as_string: '2020-09-09T00:00:00.000Z', key: 1599609600000, doc_count: 41500 },
                { key_as_string: '2020-09-09T00:45:00.000Z', key: 1599612300000, doc_count: 42373 },
                { key_as_string: '2020-09-09T01:30:00.000Z', key: 1599615000000, doc_count: 49785 },
                { key_as_string: '2020-09-09T02:15:00.000Z', key: 1599617700000, doc_count: 42237 },
                { key_as_string: '2020-09-09T03:00:00.000Z', key: 1599620400000, doc_count: 43114 },
                { key_as_string: '2020-09-09T03:45:00.000Z', key: 1599623100000, doc_count: 40716 },
                { key_as_string: '2020-09-09T04:30:00.000Z', key: 1599625800000, doc_count: 39248 },
                { key_as_string: '2020-09-09T05:15:00.000Z', key: 1599628500000, doc_count: 37674 },
                { key_as_string: '2020-09-09T06:00:00.000Z', key: 1599631200000, doc_count: 41072 },
                { key_as_string: '2020-09-09T06:45:00.000Z', key: 1599633900000, doc_count: 37049 },
                { key_as_string: '2020-09-09T07:30:00.000Z', key: 1599636600000, doc_count: 38561 },
                { key_as_string: '2020-09-09T08:15:00.000Z', key: 1599639300000, doc_count: 40895 },
                { key_as_string: '2020-09-09T09:00:00.000Z', key: 1599642000000, doc_count: 45490 },
                { key_as_string: '2020-09-09T09:45:00.000Z', key: 1599644700000, doc_count: 46559 },
                { key_as_string: '2020-09-09T10:30:00.000Z', key: 1599647400000, doc_count: 40020 },
                { key_as_string: '2020-09-09T11:15:00.000Z', key: 1599650100000, doc_count: 44335 },
                { key_as_string: '2020-09-09T12:00:00.000Z', key: 1599652800000, doc_count: 47252 },
                { key_as_string: '2020-09-09T12:45:00.000Z', key: 1599655500000, doc_count: 48744 },
                { key_as_string: '2020-09-09T13:30:00.000Z', key: 1599658200000, doc_count: 55756 },
                { key_as_string: '2020-09-09T14:15:00.000Z', key: 1599660900000, doc_count: 56887 },
                { key_as_string: '2020-09-09T15:00:00.000Z', key: 1599663600000, doc_count: 66920 },
                { key_as_string: '2020-09-09T15:45:00.000Z', key: 1599666300000, doc_count: 40976 },
              ],
            },
          },
          {
            key: 'end',
            doc_count: 18413,
            events: {
              buckets: [
                { key_as_string: '2020-09-08T15:45:00.000Z', key: 1599579900000, doc_count: 226 },
                { key_as_string: '2020-09-08T16:30:00.000Z', key: 1599582600000, doc_count: 547 },
                { key_as_string: '2020-09-08T17:15:00.000Z', key: 1599585300000, doc_count: 532 },
                { key_as_string: '2020-09-08T18:00:00.000Z', key: 1599588000000, doc_count: 551 },
                { key_as_string: '2020-09-08T18:45:00.000Z', key: 1599590700000, doc_count: 543 },
                { key_as_string: '2020-09-08T19:30:00.000Z', key: 1599593400000, doc_count: 547 },
                { key_as_string: '2020-09-08T20:15:00.000Z', key: 1599596100000, doc_count: 656 },
                { key_as_string: '2020-09-08T21:00:00.000Z', key: 1599598800000, doc_count: 543 },
                { key_as_string: '2020-09-08T21:45:00.000Z', key: 1599601500000, doc_count: 616 },
                { key_as_string: '2020-09-08T22:30:00.000Z', key: 1599604200000, doc_count: 539 },
                { key_as_string: '2020-09-08T23:15:00.000Z', key: 1599606900000, doc_count: 539 },
                { key_as_string: '2020-09-09T00:00:00.000Z', key: 1599609600000, doc_count: 547 },
                { key_as_string: '2020-09-09T00:45:00.000Z', key: 1599612300000, doc_count: 616 },
                { key_as_string: '2020-09-09T01:30:00.000Z', key: 1599615000000, doc_count: 640 },
                { key_as_string: '2020-09-09T02:15:00.000Z', key: 1599617700000, doc_count: 614 },
                { key_as_string: '2020-09-09T03:00:00.000Z', key: 1599620400000, doc_count: 545 },
                { key_as_string: '2020-09-09T03:45:00.000Z', key: 1599623100000, doc_count: 537 },
                { key_as_string: '2020-09-09T04:30:00.000Z', key: 1599625800000, doc_count: 544 },
                { key_as_string: '2020-09-09T05:15:00.000Z', key: 1599628500000, doc_count: 571 },
                { key_as_string: '2020-09-09T06:00:00.000Z', key: 1599631200000, doc_count: 743 },
                { key_as_string: '2020-09-09T06:45:00.000Z', key: 1599633900000, doc_count: 560 },
                { key_as_string: '2020-09-09T07:30:00.000Z', key: 1599636600000, doc_count: 598 },
                { key_as_string: '2020-09-09T08:15:00.000Z', key: 1599639300000, doc_count: 613 },
                { key_as_string: '2020-09-09T09:00:00.000Z', key: 1599642000000, doc_count: 563 },
                { key_as_string: '2020-09-09T09:45:00.000Z', key: 1599644700000, doc_count: 540 },
                { key_as_string: '2020-09-09T10:30:00.000Z', key: 1599647400000, doc_count: 538 },
                { key_as_string: '2020-09-09T11:15:00.000Z', key: 1599650100000, doc_count: 549 },
                { key_as_string: '2020-09-09T12:00:00.000Z', key: 1599652800000, doc_count: 561 },
                { key_as_string: '2020-09-09T12:45:00.000Z', key: 1599655500000, doc_count: 554 },
                { key_as_string: '2020-09-09T13:30:00.000Z', key: 1599658200000, doc_count: 561 },
                { key_as_string: '2020-09-09T14:15:00.000Z', key: 1599660900000, doc_count: 542 },
                { key_as_string: '2020-09-09T15:00:00.000Z', key: 1599663600000, doc_count: 712 },
                { key_as_string: '2020-09-09T15:45:00.000Z', key: 1599666300000, doc_count: 326 },
              ],
            },
          },
          {
            key: 'fork',
            doc_count: 18412,
            events: {
              buckets: [
                { key_as_string: '2020-09-08T15:45:00.000Z', key: 1599579900000, doc_count: 226 },
                { key_as_string: '2020-09-08T16:30:00.000Z', key: 1599582600000, doc_count: 546 },
                { key_as_string: '2020-09-08T17:15:00.000Z', key: 1599585300000, doc_count: 532 },
                { key_as_string: '2020-09-08T18:00:00.000Z', key: 1599588000000, doc_count: 551 },
                { key_as_string: '2020-09-08T18:45:00.000Z', key: 1599590700000, doc_count: 543 },
                { key_as_string: '2020-09-08T19:30:00.000Z', key: 1599593400000, doc_count: 547 },
                { key_as_string: '2020-09-08T20:15:00.000Z', key: 1599596100000, doc_count: 656 },
                { key_as_string: '2020-09-08T21:00:00.000Z', key: 1599598800000, doc_count: 543 },
                { key_as_string: '2020-09-08T21:45:00.000Z', key: 1599601500000, doc_count: 616 },
                { key_as_string: '2020-09-08T22:30:00.000Z', key: 1599604200000, doc_count: 539 },
                { key_as_string: '2020-09-08T23:15:00.000Z', key: 1599606900000, doc_count: 539 },
                { key_as_string: '2020-09-09T00:00:00.000Z', key: 1599609600000, doc_count: 547 },
                { key_as_string: '2020-09-09T00:45:00.000Z', key: 1599612300000, doc_count: 616 },
                { key_as_string: '2020-09-09T01:30:00.000Z', key: 1599615000000, doc_count: 640 },
                { key_as_string: '2020-09-09T02:15:00.000Z', key: 1599617700000, doc_count: 614 },
                { key_as_string: '2020-09-09T03:00:00.000Z', key: 1599620400000, doc_count: 545 },
                { key_as_string: '2020-09-09T03:45:00.000Z', key: 1599623100000, doc_count: 537 },
                { key_as_string: '2020-09-09T04:30:00.000Z', key: 1599625800000, doc_count: 544 },
                { key_as_string: '2020-09-09T05:15:00.000Z', key: 1599628500000, doc_count: 571 },
                { key_as_string: '2020-09-09T06:00:00.000Z', key: 1599631200000, doc_count: 743 },
                { key_as_string: '2020-09-09T06:45:00.000Z', key: 1599633900000, doc_count: 560 },
                { key_as_string: '2020-09-09T07:30:00.000Z', key: 1599636600000, doc_count: 598 },
                { key_as_string: '2020-09-09T08:15:00.000Z', key: 1599639300000, doc_count: 613 },
                { key_as_string: '2020-09-09T09:00:00.000Z', key: 1599642000000, doc_count: 563 },
                { key_as_string: '2020-09-09T09:45:00.000Z', key: 1599644700000, doc_count: 540 },
                { key_as_string: '2020-09-09T10:30:00.000Z', key: 1599647400000, doc_count: 538 },
                { key_as_string: '2020-09-09T11:15:00.000Z', key: 1599650100000, doc_count: 549 },
                { key_as_string: '2020-09-09T12:00:00.000Z', key: 1599652800000, doc_count: 561 },
                { key_as_string: '2020-09-09T12:45:00.000Z', key: 1599655500000, doc_count: 554 },
                { key_as_string: '2020-09-09T13:30:00.000Z', key: 1599658200000, doc_count: 561 },
                { key_as_string: '2020-09-09T14:15:00.000Z', key: 1599660900000, doc_count: 542 },
                { key_as_string: '2020-09-09T15:00:00.000Z', key: 1599663600000, doc_count: 712 },
                { key_as_string: '2020-09-09T15:45:00.000Z', key: 1599666300000, doc_count: 326 },
              ],
            },
          },
          {
            key: 'exec',
            doc_count: 15183,
            events: {
              buckets: [
                { key_as_string: '2020-09-08T15:45:00.000Z', key: 1599579900000, doc_count: 189 },
                { key_as_string: '2020-09-08T16:30:00.000Z', key: 1599582600000, doc_count: 456 },
                { key_as_string: '2020-09-08T17:15:00.000Z', key: 1599585300000, doc_count: 445 },
                { key_as_string: '2020-09-08T18:00:00.000Z', key: 1599588000000, doc_count: 458 },
                { key_as_string: '2020-09-08T18:45:00.000Z', key: 1599590700000, doc_count: 455 },
                { key_as_string: '2020-09-08T19:30:00.000Z', key: 1599593400000, doc_count: 457 },
                { key_as_string: '2020-09-08T20:15:00.000Z', key: 1599596100000, doc_count: 511 },
                { key_as_string: '2020-09-08T21:00:00.000Z', key: 1599598800000, doc_count: 455 },
                { key_as_string: '2020-09-08T21:45:00.000Z', key: 1599601500000, doc_count: 493 },
                { key_as_string: '2020-09-08T22:30:00.000Z', key: 1599604200000, doc_count: 451 },
                { key_as_string: '2020-09-08T23:15:00.000Z', key: 1599606900000, doc_count: 453 },
                { key_as_string: '2020-09-09T00:00:00.000Z', key: 1599609600000, doc_count: 460 },
                { key_as_string: '2020-09-09T00:45:00.000Z', key: 1599612300000, doc_count: 521 },
                { key_as_string: '2020-09-09T01:30:00.000Z', key: 1599615000000, doc_count: 504 },
                { key_as_string: '2020-09-09T02:15:00.000Z', key: 1599617700000, doc_count: 490 },
                { key_as_string: '2020-09-09T03:00:00.000Z', key: 1599620400000, doc_count: 457 },
                { key_as_string: '2020-09-09T03:45:00.000Z', key: 1599623100000, doc_count: 447 },
                { key_as_string: '2020-09-09T04:30:00.000Z', key: 1599625800000, doc_count: 454 },
                { key_as_string: '2020-09-09T05:15:00.000Z', key: 1599628500000, doc_count: 469 },
                { key_as_string: '2020-09-09T06:00:00.000Z', key: 1599631200000, doc_count: 642 },
                { key_as_string: '2020-09-09T06:45:00.000Z', key: 1599633900000, doc_count: 465 },
                { key_as_string: '2020-09-09T07:30:00.000Z', key: 1599636600000, doc_count: 481 },
                { key_as_string: '2020-09-09T08:15:00.000Z', key: 1599639300000, doc_count: 489 },
                { key_as_string: '2020-09-09T09:00:00.000Z', key: 1599642000000, doc_count: 466 },
                { key_as_string: '2020-09-09T09:45:00.000Z', key: 1599644700000, doc_count: 452 },
                { key_as_string: '2020-09-09T10:30:00.000Z', key: 1599647400000, doc_count: 448 },
                { key_as_string: '2020-09-09T11:15:00.000Z', key: 1599650100000, doc_count: 457 },
                { key_as_string: '2020-09-09T12:00:00.000Z', key: 1599652800000, doc_count: 471 },
                { key_as_string: '2020-09-09T12:45:00.000Z', key: 1599655500000, doc_count: 460 },
                { key_as_string: '2020-09-09T13:30:00.000Z', key: 1599658200000, doc_count: 463 },
                { key_as_string: '2020-09-09T14:15:00.000Z', key: 1599660900000, doc_count: 455 },
                { key_as_string: '2020-09-09T15:00:00.000Z', key: 1599663600000, doc_count: 547 },
                { key_as_string: '2020-09-09T15:45:00.000Z', key: 1599666300000, doc_count: 262 },
              ],
            },
          },
          {
            key: 'disconnect_received',
            doc_count: 4998,
            events: {
              buckets: [
                { key_as_string: '2020-09-08T15:45:00.000Z', key: 1599579900000, doc_count: 59 },
                { key_as_string: '2020-09-08T16:30:00.000Z', key: 1599582600000, doc_count: 151 },
                { key_as_string: '2020-09-08T17:15:00.000Z', key: 1599585300000, doc_count: 139 },
                { key_as_string: '2020-09-08T18:00:00.000Z', key: 1599588000000, doc_count: 144 },
                { key_as_string: '2020-09-08T18:45:00.000Z', key: 1599590700000, doc_count: 143 },
                { key_as_string: '2020-09-08T19:30:00.000Z', key: 1599593400000, doc_count: 144 },
                { key_as_string: '2020-09-08T20:15:00.000Z', key: 1599596100000, doc_count: 202 },
                { key_as_string: '2020-09-08T21:00:00.000Z', key: 1599598800000, doc_count: 142 },
                { key_as_string: '2020-09-08T21:45:00.000Z', key: 1599601500000, doc_count: 180 },
                { key_as_string: '2020-09-08T22:30:00.000Z', key: 1599604200000, doc_count: 144 },
                { key_as_string: '2020-09-08T23:15:00.000Z', key: 1599606900000, doc_count: 143 },
                { key_as_string: '2020-09-09T00:00:00.000Z', key: 1599609600000, doc_count: 137 },
                { key_as_string: '2020-09-09T00:45:00.000Z', key: 1599612300000, doc_count: 150 },
                { key_as_string: '2020-09-09T01:30:00.000Z', key: 1599615000000, doc_count: 195 },
                { key_as_string: '2020-09-09T02:15:00.000Z', key: 1599617700000, doc_count: 178 },
                { key_as_string: '2020-09-09T03:00:00.000Z', key: 1599620400000, doc_count: 144 },
                { key_as_string: '2020-09-09T03:45:00.000Z', key: 1599623100000, doc_count: 143 },
                { key_as_string: '2020-09-09T04:30:00.000Z', key: 1599625800000, doc_count: 142 },
                { key_as_string: '2020-09-09T05:15:00.000Z', key: 1599628500000, doc_count: 157 },
                { key_as_string: '2020-09-09T06:00:00.000Z', key: 1599631200000, doc_count: 166 },
                { key_as_string: '2020-09-09T06:45:00.000Z', key: 1599633900000, doc_count: 153 },
                { key_as_string: '2020-09-09T07:30:00.000Z', key: 1599636600000, doc_count: 168 },
                { key_as_string: '2020-09-09T08:15:00.000Z', key: 1599639300000, doc_count: 175 },
                { key_as_string: '2020-09-09T09:00:00.000Z', key: 1599642000000, doc_count: 158 },
                { key_as_string: '2020-09-09T09:45:00.000Z', key: 1599644700000, doc_count: 142 },
                { key_as_string: '2020-09-09T10:30:00.000Z', key: 1599647400000, doc_count: 144 },
                { key_as_string: '2020-09-09T11:15:00.000Z', key: 1599650100000, doc_count: 147 },
                { key_as_string: '2020-09-09T12:00:00.000Z', key: 1599652800000, doc_count: 139 },
                { key_as_string: '2020-09-09T12:45:00.000Z', key: 1599655500000, doc_count: 145 },
                { key_as_string: '2020-09-09T13:30:00.000Z', key: 1599658200000, doc_count: 158 },
                { key_as_string: '2020-09-09T14:15:00.000Z', key: 1599660900000, doc_count: 137 },
                { key_as_string: '2020-09-09T15:00:00.000Z', key: 1599663600000, doc_count: 234 },
                { key_as_string: '2020-09-09T15:45:00.000Z', key: 1599666300000, doc_count: 95 },
              ],
            },
          },
          {
            key: 'connection_attempted',
            doc_count: 4534,
            events: {
              buckets: [
                { key_as_string: '2020-09-08T15:45:00.000Z', key: 1599579900000, doc_count: 60 },
                { key_as_string: '2020-09-08T16:30:00.000Z', key: 1599582600000, doc_count: 145 },
                { key_as_string: '2020-09-08T17:15:00.000Z', key: 1599585300000, doc_count: 138 },
                { key_as_string: '2020-09-08T18:00:00.000Z', key: 1599588000000, doc_count: 144 },
                { key_as_string: '2020-09-08T18:45:00.000Z', key: 1599590700000, doc_count: 140 },
                { key_as_string: '2020-09-08T19:30:00.000Z', key: 1599593400000, doc_count: 144 },
                { key_as_string: '2020-09-08T20:15:00.000Z', key: 1599596100000, doc_count: 145 },
                { key_as_string: '2020-09-08T21:00:00.000Z', key: 1599598800000, doc_count: 137 },
                { key_as_string: '2020-09-08T21:45:00.000Z', key: 1599601500000, doc_count: 142 },
                { key_as_string: '2020-09-08T22:30:00.000Z', key: 1599604200000, doc_count: 142 },
                { key_as_string: '2020-09-08T23:15:00.000Z', key: 1599606900000, doc_count: 143 },
                { key_as_string: '2020-09-09T00:00:00.000Z', key: 1599609600000, doc_count: 132 },
                { key_as_string: '2020-09-09T00:45:00.000Z', key: 1599612300000, doc_count: 153 },
                { key_as_string: '2020-09-09T01:30:00.000Z', key: 1599615000000, doc_count: 143 },
                { key_as_string: '2020-09-09T02:15:00.000Z', key: 1599617700000, doc_count: 142 },
                { key_as_string: '2020-09-09T03:00:00.000Z', key: 1599620400000, doc_count: 143 },
                { key_as_string: '2020-09-09T03:45:00.000Z', key: 1599623100000, doc_count: 142 },
                { key_as_string: '2020-09-09T04:30:00.000Z', key: 1599625800000, doc_count: 140 },
                { key_as_string: '2020-09-09T05:15:00.000Z', key: 1599628500000, doc_count: 140 },
                { key_as_string: '2020-09-09T06:00:00.000Z', key: 1599631200000, doc_count: 148 },
                { key_as_string: '2020-09-09T06:45:00.000Z', key: 1599633900000, doc_count: 142 },
                { key_as_string: '2020-09-09T07:30:00.000Z', key: 1599636600000, doc_count: 139 },
                { key_as_string: '2020-09-09T08:15:00.000Z', key: 1599639300000, doc_count: 139 },
                { key_as_string: '2020-09-09T09:00:00.000Z', key: 1599642000000, doc_count: 142 },
                { key_as_string: '2020-09-09T09:45:00.000Z', key: 1599644700000, doc_count: 142 },
                { key_as_string: '2020-09-09T10:30:00.000Z', key: 1599647400000, doc_count: 143 },
                { key_as_string: '2020-09-09T11:15:00.000Z', key: 1599650100000, doc_count: 141 },
                { key_as_string: '2020-09-09T12:00:00.000Z', key: 1599652800000, doc_count: 137 },
                { key_as_string: '2020-09-09T12:45:00.000Z', key: 1599655500000, doc_count: 141 },
                { key_as_string: '2020-09-09T13:30:00.000Z', key: 1599658200000, doc_count: 144 },
                { key_as_string: '2020-09-09T14:15:00.000Z', key: 1599660900000, doc_count: 138 },
                { key_as_string: '2020-09-09T15:00:00.000Z', key: 1599663600000, doc_count: 145 },
                { key_as_string: '2020-09-09T15:45:00.000Z', key: 1599666300000, doc_count: 78 },
              ],
            },
          },
          {
            key: 'creation',
            doc_count: 1880,
            events: {
              buckets: [
                { key_as_string: '2020-09-08T15:45:00.000Z', key: 1599579900000, doc_count: 24 },
                { key_as_string: '2020-09-08T16:30:00.000Z', key: 1599582600000, doc_count: 53 },
                { key_as_string: '2020-09-08T17:15:00.000Z', key: 1599585300000, doc_count: 50 },
                { key_as_string: '2020-09-08T18:00:00.000Z', key: 1599588000000, doc_count: 54 },
                { key_as_string: '2020-09-08T18:45:00.000Z', key: 1599590700000, doc_count: 55 },
                { key_as_string: '2020-09-08T19:30:00.000Z', key: 1599593400000, doc_count: 53 },
                { key_as_string: '2020-09-08T20:15:00.000Z', key: 1599596100000, doc_count: 54 },
                { key_as_string: '2020-09-08T21:00:00.000Z', key: 1599598800000, doc_count: 54 },
                { key_as_string: '2020-09-08T21:45:00.000Z', key: 1599601500000, doc_count: 55 },
                { key_as_string: '2020-09-08T22:30:00.000Z', key: 1599604200000, doc_count: 52 },
                { key_as_string: '2020-09-08T23:15:00.000Z', key: 1599606900000, doc_count: 51 },
                { key_as_string: '2020-09-09T00:00:00.000Z', key: 1599609600000, doc_count: 58 },
                { key_as_string: '2020-09-09T00:45:00.000Z', key: 1599612300000, doc_count: 122 },
                { key_as_string: '2020-09-09T01:30:00.000Z', key: 1599615000000, doc_count: 54 },
                { key_as_string: '2020-09-09T02:15:00.000Z', key: 1599617700000, doc_count: 54 },
                { key_as_string: '2020-09-09T03:00:00.000Z', key: 1599620400000, doc_count: 56 },
                { key_as_string: '2020-09-09T03:45:00.000Z', key: 1599623100000, doc_count: 53 },
                { key_as_string: '2020-09-09T04:30:00.000Z', key: 1599625800000, doc_count: 55 },
                { key_as_string: '2020-09-09T05:15:00.000Z', key: 1599628500000, doc_count: 51 },
                { key_as_string: '2020-09-09T06:00:00.000Z', key: 1599631200000, doc_count: 144 },
                { key_as_string: '2020-09-09T06:45:00.000Z', key: 1599633900000, doc_count: 54 },
                { key_as_string: '2020-09-09T07:30:00.000Z', key: 1599636600000, doc_count: 53 },
                { key_as_string: '2020-09-09T08:15:00.000Z', key: 1599639300000, doc_count: 51 },
                { key_as_string: '2020-09-09T09:00:00.000Z', key: 1599642000000, doc_count: 57 },
                { key_as_string: '2020-09-09T09:45:00.000Z', key: 1599644700000, doc_count: 55 },
                { key_as_string: '2020-09-09T10:30:00.000Z', key: 1599647400000, doc_count: 52 },
                { key_as_string: '2020-09-09T11:15:00.000Z', key: 1599650100000, doc_count: 52 },
                { key_as_string: '2020-09-09T12:00:00.000Z', key: 1599652800000, doc_count: 57 },
                { key_as_string: '2020-09-09T12:45:00.000Z', key: 1599655500000, doc_count: 56 },
                { key_as_string: '2020-09-09T13:30:00.000Z', key: 1599658200000, doc_count: 53 },
                { key_as_string: '2020-09-09T14:15:00.000Z', key: 1599660900000, doc_count: 51 },
                { key_as_string: '2020-09-09T15:00:00.000Z', key: 1599663600000, doc_count: 56 },
                { key_as_string: '2020-09-09T15:45:00.000Z', key: 1599666300000, doc_count: 31 },
              ],
            },
          },
          {
            key: 'deletion',
            doc_count: 1869,
            events: {
              buckets: [
                { key_as_string: '2020-09-08T15:45:00.000Z', key: 1599579900000, doc_count: 23 },
                { key_as_string: '2020-09-08T16:30:00.000Z', key: 1599582600000, doc_count: 53 },
                { key_as_string: '2020-09-08T17:15:00.000Z', key: 1599585300000, doc_count: 50 },
                { key_as_string: '2020-09-08T18:00:00.000Z', key: 1599588000000, doc_count: 54 },
                { key_as_string: '2020-09-08T18:45:00.000Z', key: 1599590700000, doc_count: 54 },
                { key_as_string: '2020-09-08T19:30:00.000Z', key: 1599593400000, doc_count: 53 },
                { key_as_string: '2020-09-08T20:15:00.000Z', key: 1599596100000, doc_count: 53 },
                { key_as_string: '2020-09-08T21:00:00.000Z', key: 1599598800000, doc_count: 54 },
                { key_as_string: '2020-09-08T21:45:00.000Z', key: 1599601500000, doc_count: 55 },
                { key_as_string: '2020-09-08T22:30:00.000Z', key: 1599604200000, doc_count: 52 },
                { key_as_string: '2020-09-08T23:15:00.000Z', key: 1599606900000, doc_count: 51 },
                { key_as_string: '2020-09-09T00:00:00.000Z', key: 1599609600000, doc_count: 55 },
                { key_as_string: '2020-09-09T00:45:00.000Z', key: 1599612300000, doc_count: 121 },
                { key_as_string: '2020-09-09T01:30:00.000Z', key: 1599615000000, doc_count: 54 },
                { key_as_string: '2020-09-09T02:15:00.000Z', key: 1599617700000, doc_count: 53 },
                { key_as_string: '2020-09-09T03:00:00.000Z', key: 1599620400000, doc_count: 55 },
                { key_as_string: '2020-09-09T03:45:00.000Z', key: 1599623100000, doc_count: 53 },
                { key_as_string: '2020-09-09T04:30:00.000Z', key: 1599625800000, doc_count: 54 },
                { key_as_string: '2020-09-09T05:15:00.000Z', key: 1599628500000, doc_count: 51 },
                { key_as_string: '2020-09-09T06:00:00.000Z', key: 1599631200000, doc_count: 146 },
                { key_as_string: '2020-09-09T06:45:00.000Z', key: 1599633900000, doc_count: 54 },
                { key_as_string: '2020-09-09T07:30:00.000Z', key: 1599636600000, doc_count: 53 },
                { key_as_string: '2020-09-09T08:15:00.000Z', key: 1599639300000, doc_count: 51 },
                { key_as_string: '2020-09-09T09:00:00.000Z', key: 1599642000000, doc_count: 55 },
                { key_as_string: '2020-09-09T09:45:00.000Z', key: 1599644700000, doc_count: 55 },
                { key_as_string: '2020-09-09T10:30:00.000Z', key: 1599647400000, doc_count: 52 },
                { key_as_string: '2020-09-09T11:15:00.000Z', key: 1599650100000, doc_count: 55 },
                { key_as_string: '2020-09-09T12:00:00.000Z', key: 1599652800000, doc_count: 55 },
                { key_as_string: '2020-09-09T12:45:00.000Z', key: 1599655500000, doc_count: 55 },
                { key_as_string: '2020-09-09T13:30:00.000Z', key: 1599658200000, doc_count: 53 },
                { key_as_string: '2020-09-09T14:15:00.000Z', key: 1599660900000, doc_count: 51 },
                { key_as_string: '2020-09-09T15:00:00.000Z', key: 1599663600000, doc_count: 55 },
                { key_as_string: '2020-09-09T15:45:00.000Z', key: 1599666300000, doc_count: 31 },
              ],
            },
          },
          {
            key: 'File Delete (rule: FileDelete)',
            doc_count: 1831,
            events: {
              buckets: [
                { key_as_string: '2020-09-08T15:45:00.000Z', key: 1599579900000, doc_count: 19 },
                { key_as_string: '2020-09-08T16:30:00.000Z', key: 1599582600000, doc_count: 46 },
                { key_as_string: '2020-09-08T17:15:00.000Z', key: 1599585300000, doc_count: 47 },
                { key_as_string: '2020-09-08T18:00:00.000Z', key: 1599588000000, doc_count: 47 },
                { key_as_string: '2020-09-08T18:45:00.000Z', key: 1599590700000, doc_count: 47 },
                { key_as_string: '2020-09-08T19:30:00.000Z', key: 1599593400000, doc_count: 45 },
                { key_as_string: '2020-09-08T20:15:00.000Z', key: 1599596100000, doc_count: 48 },
                { key_as_string: '2020-09-08T21:00:00.000Z', key: 1599598800000, doc_count: 46 },
                { key_as_string: '2020-09-08T21:45:00.000Z', key: 1599601500000, doc_count: 45 },
                { key_as_string: '2020-09-08T22:30:00.000Z', key: 1599604200000, doc_count: 47 },
                { key_as_string: '2020-09-08T23:15:00.000Z', key: 1599606900000, doc_count: 47 },
                { key_as_string: '2020-09-09T00:00:00.000Z', key: 1599609600000, doc_count: 60 },
                { key_as_string: '2020-09-09T00:45:00.000Z', key: 1599612300000, doc_count: 45 },
                { key_as_string: '2020-09-09T01:30:00.000Z', key: 1599615000000, doc_count: 46 },
                { key_as_string: '2020-09-09T02:15:00.000Z', key: 1599617700000, doc_count: 46 },
                { key_as_string: '2020-09-09T03:00:00.000Z', key: 1599620400000, doc_count: 47 },
                { key_as_string: '2020-09-09T03:45:00.000Z', key: 1599623100000, doc_count: 88 },
                { key_as_string: '2020-09-09T04:30:00.000Z', key: 1599625800000, doc_count: 53 },
                { key_as_string: '2020-09-09T05:15:00.000Z', key: 1599628500000, doc_count: 46 },
                { key_as_string: '2020-09-09T06:00:00.000Z', key: 1599631200000, doc_count: 49 },
                { key_as_string: '2020-09-09T06:45:00.000Z', key: 1599633900000, doc_count: 45 },
                { key_as_string: '2020-09-09T07:30:00.000Z', key: 1599636600000, doc_count: 48 },
                { key_as_string: '2020-09-09T08:15:00.000Z', key: 1599639300000, doc_count: 46 },
                { key_as_string: '2020-09-09T09:00:00.000Z', key: 1599642000000, doc_count: 46 },
                { key_as_string: '2020-09-09T09:45:00.000Z', key: 1599644700000, doc_count: 45 },
                { key_as_string: '2020-09-09T10:30:00.000Z', key: 1599647400000, doc_count: 47 },
                { key_as_string: '2020-09-09T11:15:00.000Z', key: 1599650100000, doc_count: 47 },
                { key_as_string: '2020-09-09T12:00:00.000Z', key: 1599652800000, doc_count: 45 },
                { key_as_string: '2020-09-09T12:45:00.000Z', key: 1599655500000, doc_count: 331 },
                { key_as_string: '2020-09-09T13:30:00.000Z', key: 1599658200000, doc_count: 45 },
                { key_as_string: '2020-09-09T14:15:00.000Z', key: 1599660900000, doc_count: 47 },
                { key_as_string: '2020-09-09T15:00:00.000Z', key: 1599663600000, doc_count: 47 },
                { key_as_string: '2020-09-09T15:45:00.000Z', key: 1599666300000, doc_count: 28 },
              ],
            },
          },
          {
            key: 'session_id_change',
            doc_count: 647,
            events: {
              buckets: [
                { key_as_string: '2020-09-08T15:45:00.000Z', key: 1599579900000, doc_count: 3 },
                { key_as_string: '2020-09-08T16:30:00.000Z', key: 1599582600000, doc_count: 9 },
                { key_as_string: '2020-09-08T17:15:00.000Z', key: 1599585300000, doc_count: 7 },
                { key_as_string: '2020-09-08T18:00:00.000Z', key: 1599588000000, doc_count: 10 },
                { key_as_string: '2020-09-08T18:45:00.000Z', key: 1599590700000, doc_count: 7 },
                { key_as_string: '2020-09-08T19:30:00.000Z', key: 1599593400000, doc_count: 10 },
                { key_as_string: '2020-09-08T20:15:00.000Z', key: 1599596100000, doc_count: 63 },
                { key_as_string: '2020-09-08T21:00:00.000Z', key: 1599598800000, doc_count: 7 },
                { key_as_string: '2020-09-08T21:45:00.000Z', key: 1599601500000, doc_count: 45 },
                { key_as_string: '2020-09-08T22:30:00.000Z', key: 1599604200000, doc_count: 4 },
                { key_as_string: '2020-09-08T23:15:00.000Z', key: 1599606900000, doc_count: 5 },
                { key_as_string: '2020-09-09T00:00:00.000Z', key: 1599609600000, doc_count: 6 },
                { key_as_string: '2020-09-09T00:45:00.000Z', key: 1599612300000, doc_count: 6 },
                { key_as_string: '2020-09-09T01:30:00.000Z', key: 1599615000000, doc_count: 55 },
                { key_as_string: '2020-09-09T02:15:00.000Z', key: 1599617700000, doc_count: 43 },
                { key_as_string: '2020-09-09T03:00:00.000Z', key: 1599620400000, doc_count: 8 },
                { key_as_string: '2020-09-09T03:45:00.000Z', key: 1599623100000, doc_count: 9 },
                { key_as_string: '2020-09-09T04:30:00.000Z', key: 1599625800000, doc_count: 7 },
                { key_as_string: '2020-09-09T05:15:00.000Z', key: 1599628500000, doc_count: 21 },
                { key_as_string: '2020-09-09T06:00:00.000Z', key: 1599631200000, doc_count: 26 },
                { key_as_string: '2020-09-09T06:45:00.000Z', key: 1599633900000, doc_count: 17 },
                { key_as_string: '2020-09-09T07:30:00.000Z', key: 1599636600000, doc_count: 34 },
                { key_as_string: '2020-09-09T08:15:00.000Z', key: 1599639300000, doc_count: 41 },
                { key_as_string: '2020-09-09T09:00:00.000Z', key: 1599642000000, doc_count: 18 },
                { key_as_string: '2020-09-09T09:45:00.000Z', key: 1599644700000, doc_count: 4 },
                { key_as_string: '2020-09-09T10:30:00.000Z', key: 1599647400000, doc_count: 11 },
                { key_as_string: '2020-09-09T11:15:00.000Z', key: 1599650100000, doc_count: 9 },
                { key_as_string: '2020-09-09T12:00:00.000Z', key: 1599652800000, doc_count: 7 },
                { key_as_string: '2020-09-09T12:45:00.000Z', key: 1599655500000, doc_count: 12 },
                { key_as_string: '2020-09-09T13:30:00.000Z', key: 1599658200000, doc_count: 16 },
                { key_as_string: '2020-09-09T14:15:00.000Z', key: 1599660900000, doc_count: 7 },
                { key_as_string: '2020-09-09T15:00:00.000Z', key: 1599663600000, doc_count: 99 },
                { key_as_string: '2020-09-09T15:45:00.000Z', key: 1599666300000, doc_count: 21 },
              ],
            },
          },
        ],
      },
    },
  },
  total: 21,
  loaded: 21,
};

export const formattedEventsSearchStrategyResponse: MatrixHistogramStrategyResponse = {
  ...mockEventsSearchStrategyResponse,
  inspect: {
    dsl: [
      JSON.stringify(
        {
          index: [
            'apm-*-transaction*',
            'traces-apm*',
            'auditbeat-*',
            'endgame-*',
            'filebeat-*',
            'logs-*',
            'packetbeat-*',
            'winlogbeat-*',
          ],
          allow_no_indices: true,
          ignore_unavailable: true,
          track_total_hits: true,
          body: {
            aggregations: {
              eventActionGroup: {
                terms: {
                  field: 'event.action',
                  missing: 'All others',
                  order: { _count: 'desc' },
                  size: 10,
                },
                aggs: {
                  events: {
                    date_histogram: {
                      field: '@timestamp',
                      fixed_interval: '2700000ms',
                      min_doc_count: 0,
                      extended_bounds: { min: 1599581486215, max: 1599667886215 },
                    },
                  },
                },
              },
            },
            query: {
              bool: {
                filter: [
                  { bool: { must: [], filter: [{ match_all: {} }], should: [], must_not: [] } },
                  {
                    range: {
                      '@timestamp': {
                        gte: '2020-09-08T16:11:26.215Z',
                        lte: '2020-09-09T16:11:26.215Z',
                        format: 'strict_date_optional_time',
                      },
                    },
                  },
                ],
              },
            },
            runtime_mappings: {
              '@a.runtime.field': {
                script: {
                  source: 'emit("Radically mocked dude: " + doc[\'host.name\'].value)',
                },
                type: 'keyword',
              },
            },
            size: 0,
          },
        },
        null,
        2
      ),
    ],
  },
  totalCount: 0,
  matrixHistogramData: [
    { x: 1599579900000, y: 26124, g: 'All others' },
    { x: 1599582600000, y: 62910, g: 'All others' },
    { x: 1599585300000, y: 60326, g: 'All others' },
    { x: 1599588000000, y: 56144, g: 'All others' },
    { x: 1599590700000, y: 53614, g: 'All others' },
    { x: 1599593400000, y: 53228, g: 'All others' },
    { x: 1599596100000, y: 61195, g: 'All others' },
    { x: 1599598800000, y: 52082, g: 'All others' },
    { x: 1599601500000, y: 52697, g: 'All others' },
    { x: 1599604200000, y: 41094, g: 'All others' },
    { x: 1599606900000, y: 50164, g: 'All others' },
    { x: 1599609600000, y: 41500, g: 'All others' },
    { x: 1599612300000, y: 42373, g: 'All others' },
    { x: 1599615000000, y: 49785, g: 'All others' },
    { x: 1599617700000, y: 42237, g: 'All others' },
    { x: 1599620400000, y: 43114, g: 'All others' },
    { x: 1599623100000, y: 40716, g: 'All others' },
    { x: 1599625800000, y: 39248, g: 'All others' },
    { x: 1599628500000, y: 37674, g: 'All others' },
    { x: 1599631200000, y: 41072, g: 'All others' },
    { x: 1599633900000, y: 37049, g: 'All others' },
    { x: 1599636600000, y: 38561, g: 'All others' },
    { x: 1599639300000, y: 40895, g: 'All others' },
    { x: 1599642000000, y: 45490, g: 'All others' },
    { x: 1599644700000, y: 46559, g: 'All others' },
    { x: 1599647400000, y: 40020, g: 'All others' },
    { x: 1599650100000, y: 44335, g: 'All others' },
    { x: 1599652800000, y: 47252, g: 'All others' },
    { x: 1599655500000, y: 48744, g: 'All others' },
    { x: 1599658200000, y: 55756, g: 'All others' },
    { x: 1599660900000, y: 56887, g: 'All others' },
    { x: 1599663600000, y: 66920, g: 'All others' },
    { x: 1599666300000, y: 40976, g: 'All others' },
    { x: 1599579900000, y: 226, g: 'end' },
    { x: 1599582600000, y: 547, g: 'end' },
    { x: 1599585300000, y: 532, g: 'end' },
    { x: 1599588000000, y: 551, g: 'end' },
    { x: 1599590700000, y: 543, g: 'end' },
    { x: 1599593400000, y: 547, g: 'end' },
    { x: 1599596100000, y: 656, g: 'end' },
    { x: 1599598800000, y: 543, g: 'end' },
    { x: 1599601500000, y: 616, g: 'end' },
    { x: 1599604200000, y: 539, g: 'end' },
    { x: 1599606900000, y: 539, g: 'end' },
    { x: 1599609600000, y: 547, g: 'end' },
    { x: 1599612300000, y: 616, g: 'end' },
    { x: 1599615000000, y: 640, g: 'end' },
    { x: 1599617700000, y: 614, g: 'end' },
    { x: 1599620400000, y: 545, g: 'end' },
    { x: 1599623100000, y: 537, g: 'end' },
    { x: 1599625800000, y: 544, g: 'end' },
    { x: 1599628500000, y: 571, g: 'end' },
    { x: 1599631200000, y: 743, g: 'end' },
    { x: 1599633900000, y: 560, g: 'end' },
    { x: 1599636600000, y: 598, g: 'end' },
    { x: 1599639300000, y: 613, g: 'end' },
    { x: 1599642000000, y: 563, g: 'end' },
    { x: 1599644700000, y: 540, g: 'end' },
    { x: 1599647400000, y: 538, g: 'end' },
    { x: 1599650100000, y: 549, g: 'end' },
    { x: 1599652800000, y: 561, g: 'end' },
    { x: 1599655500000, y: 554, g: 'end' },
    { x: 1599658200000, y: 561, g: 'end' },
    { x: 1599660900000, y: 542, g: 'end' },
    { x: 1599663600000, y: 712, g: 'end' },
    { x: 1599666300000, y: 326, g: 'end' },
    { x: 1599579900000, y: 226, g: 'fork' },
    { x: 1599582600000, y: 546, g: 'fork' },
    { x: 1599585300000, y: 532, g: 'fork' },
    { x: 1599588000000, y: 551, g: 'fork' },
    { x: 1599590700000, y: 543, g: 'fork' },
    { x: 1599593400000, y: 547, g: 'fork' },
    { x: 1599596100000, y: 656, g: 'fork' },
    { x: 1599598800000, y: 543, g: 'fork' },
    { x: 1599601500000, y: 616, g: 'fork' },
    { x: 1599604200000, y: 539, g: 'fork' },
    { x: 1599606900000, y: 539, g: 'fork' },
    { x: 1599609600000, y: 547, g: 'fork' },
    { x: 1599612300000, y: 616, g: 'fork' },
    { x: 1599615000000, y: 640, g: 'fork' },
    { x: 1599617700000, y: 614, g: 'fork' },
    { x: 1599620400000, y: 545, g: 'fork' },
    { x: 1599623100000, y: 537, g: 'fork' },
    { x: 1599625800000, y: 544, g: 'fork' },
    { x: 1599628500000, y: 571, g: 'fork' },
    { x: 1599631200000, y: 743, g: 'fork' },
    { x: 1599633900000, y: 560, g: 'fork' },
    { x: 1599636600000, y: 598, g: 'fork' },
    { x: 1599639300000, y: 613, g: 'fork' },
    { x: 1599642000000, y: 563, g: 'fork' },
    { x: 1599644700000, y: 540, g: 'fork' },
    { x: 1599647400000, y: 538, g: 'fork' },
    { x: 1599650100000, y: 549, g: 'fork' },
    { x: 1599652800000, y: 561, g: 'fork' },
    { x: 1599655500000, y: 554, g: 'fork' },
    { x: 1599658200000, y: 561, g: 'fork' },
    { x: 1599660900000, y: 542, g: 'fork' },
    { x: 1599663600000, y: 712, g: 'fork' },
    { x: 1599666300000, y: 326, g: 'fork' },
    { x: 1599579900000, y: 189, g: 'exec' },
    { x: 1599582600000, y: 456, g: 'exec' },
    { x: 1599585300000, y: 445, g: 'exec' },
    { x: 1599588000000, y: 458, g: 'exec' },
    { x: 1599590700000, y: 455, g: 'exec' },
    { x: 1599593400000, y: 457, g: 'exec' },
    { x: 1599596100000, y: 511, g: 'exec' },
    { x: 1599598800000, y: 455, g: 'exec' },
    { x: 1599601500000, y: 493, g: 'exec' },
    { x: 1599604200000, y: 451, g: 'exec' },
    { x: 1599606900000, y: 453, g: 'exec' },
    { x: 1599609600000, y: 460, g: 'exec' },
    { x: 1599612300000, y: 521, g: 'exec' },
    { x: 1599615000000, y: 504, g: 'exec' },
    { x: 1599617700000, y: 490, g: 'exec' },
    { x: 1599620400000, y: 457, g: 'exec' },
    { x: 1599623100000, y: 447, g: 'exec' },
    { x: 1599625800000, y: 454, g: 'exec' },
    { x: 1599628500000, y: 469, g: 'exec' },
    { x: 1599631200000, y: 642, g: 'exec' },
    { x: 1599633900000, y: 465, g: 'exec' },
    { x: 1599636600000, y: 481, g: 'exec' },
    { x: 1599639300000, y: 489, g: 'exec' },
    { x: 1599642000000, y: 466, g: 'exec' },
    { x: 1599644700000, y: 452, g: 'exec' },
    { x: 1599647400000, y: 448, g: 'exec' },
    { x: 1599650100000, y: 457, g: 'exec' },
    { x: 1599652800000, y: 471, g: 'exec' },
    { x: 1599655500000, y: 460, g: 'exec' },
    { x: 1599658200000, y: 463, g: 'exec' },
    { x: 1599660900000, y: 455, g: 'exec' },
    { x: 1599663600000, y: 547, g: 'exec' },
    { x: 1599666300000, y: 262, g: 'exec' },
    { x: 1599579900000, y: 59, g: 'disconnect_received' },
    { x: 1599582600000, y: 151, g: 'disconnect_received' },
    { x: 1599585300000, y: 139, g: 'disconnect_received' },
    { x: 1599588000000, y: 144, g: 'disconnect_received' },
    { x: 1599590700000, y: 143, g: 'disconnect_received' },
    { x: 1599593400000, y: 144, g: 'disconnect_received' },
    { x: 1599596100000, y: 202, g: 'disconnect_received' },
    { x: 1599598800000, y: 142, g: 'disconnect_received' },
    { x: 1599601500000, y: 180, g: 'disconnect_received' },
    { x: 1599604200000, y: 144, g: 'disconnect_received' },
    { x: 1599606900000, y: 143, g: 'disconnect_received' },
    { x: 1599609600000, y: 137, g: 'disconnect_received' },
    { x: 1599612300000, y: 150, g: 'disconnect_received' },
    { x: 1599615000000, y: 195, g: 'disconnect_received' },
    { x: 1599617700000, y: 178, g: 'disconnect_received' },
    { x: 1599620400000, y: 144, g: 'disconnect_received' },
    { x: 1599623100000, y: 143, g: 'disconnect_received' },
    { x: 1599625800000, y: 142, g: 'disconnect_received' },
    { x: 1599628500000, y: 157, g: 'disconnect_received' },
    { x: 1599631200000, y: 166, g: 'disconnect_received' },
    { x: 1599633900000, y: 153, g: 'disconnect_received' },
    { x: 1599636600000, y: 168, g: 'disconnect_received' },
    { x: 1599639300000, y: 175, g: 'disconnect_received' },
    { x: 1599642000000, y: 158, g: 'disconnect_received' },
    { x: 1599644700000, y: 142, g: 'disconnect_received' },
    { x: 1599647400000, y: 144, g: 'disconnect_received' },
    { x: 1599650100000, y: 147, g: 'disconnect_received' },
    { x: 1599652800000, y: 139, g: 'disconnect_received' },
    { x: 1599655500000, y: 145, g: 'disconnect_received' },
    { x: 1599658200000, y: 158, g: 'disconnect_received' },
    { x: 1599660900000, y: 137, g: 'disconnect_received' },
    { x: 1599663600000, y: 234, g: 'disconnect_received' },
    { x: 1599666300000, y: 95, g: 'disconnect_received' },
    { x: 1599579900000, y: 60, g: 'connection_attempted' },
    { x: 1599582600000, y: 145, g: 'connection_attempted' },
    { x: 1599585300000, y: 138, g: 'connection_attempted' },
    { x: 1599588000000, y: 144, g: 'connection_attempted' },
    { x: 1599590700000, y: 140, g: 'connection_attempted' },
    { x: 1599593400000, y: 144, g: 'connection_attempted' },
    { x: 1599596100000, y: 145, g: 'connection_attempted' },
    { x: 1599598800000, y: 137, g: 'connection_attempted' },
    { x: 1599601500000, y: 142, g: 'connection_attempted' },
    { x: 1599604200000, y: 142, g: 'connection_attempted' },
    { x: 1599606900000, y: 143, g: 'connection_attempted' },
    { x: 1599609600000, y: 132, g: 'connection_attempted' },
    { x: 1599612300000, y: 153, g: 'connection_attempted' },
    { x: 1599615000000, y: 143, g: 'connection_attempted' },
    { x: 1599617700000, y: 142, g: 'connection_attempted' },
    { x: 1599620400000, y: 143, g: 'connection_attempted' },
    { x: 1599623100000, y: 142, g: 'connection_attempted' },
    { x: 1599625800000, y: 140, g: 'connection_attempted' },
    { x: 1599628500000, y: 140, g: 'connection_attempted' },
    { x: 1599631200000, y: 148, g: 'connection_attempted' },
    { x: 1599633900000, y: 142, g: 'connection_attempted' },
    { x: 1599636600000, y: 139, g: 'connection_attempted' },
    { x: 1599639300000, y: 139, g: 'connection_attempted' },
    { x: 1599642000000, y: 142, g: 'connection_attempted' },
    { x: 1599644700000, y: 142, g: 'connection_attempted' },
    { x: 1599647400000, y: 143, g: 'connection_attempted' },
    { x: 1599650100000, y: 141, g: 'connection_attempted' },
    { x: 1599652800000, y: 137, g: 'connection_attempted' },
    { x: 1599655500000, y: 141, g: 'connection_attempted' },
    { x: 1599658200000, y: 144, g: 'connection_attempted' },
    { x: 1599660900000, y: 138, g: 'connection_attempted' },
    { x: 1599663600000, y: 145, g: 'connection_attempted' },
    { x: 1599666300000, y: 78, g: 'connection_attempted' },
    { x: 1599579900000, y: 24, g: 'creation' },
    { x: 1599582600000, y: 53, g: 'creation' },
    { x: 1599585300000, y: 50, g: 'creation' },
    { x: 1599588000000, y: 54, g: 'creation' },
    { x: 1599590700000, y: 55, g: 'creation' },
    { x: 1599593400000, y: 53, g: 'creation' },
    { x: 1599596100000, y: 54, g: 'creation' },
    { x: 1599598800000, y: 54, g: 'creation' },
    { x: 1599601500000, y: 55, g: 'creation' },
    { x: 1599604200000, y: 52, g: 'creation' },
    { x: 1599606900000, y: 51, g: 'creation' },
    { x: 1599609600000, y: 58, g: 'creation' },
    { x: 1599612300000, y: 122, g: 'creation' },
    { x: 1599615000000, y: 54, g: 'creation' },
    { x: 1599617700000, y: 54, g: 'creation' },
    { x: 1599620400000, y: 56, g: 'creation' },
    { x: 1599623100000, y: 53, g: 'creation' },
    { x: 1599625800000, y: 55, g: 'creation' },
    { x: 1599628500000, y: 51, g: 'creation' },
    { x: 1599631200000, y: 144, g: 'creation' },
    { x: 1599633900000, y: 54, g: 'creation' },
    { x: 1599636600000, y: 53, g: 'creation' },
    { x: 1599639300000, y: 51, g: 'creation' },
    { x: 1599642000000, y: 57, g: 'creation' },
    { x: 1599644700000, y: 55, g: 'creation' },
    { x: 1599647400000, y: 52, g: 'creation' },
    { x: 1599650100000, y: 52, g: 'creation' },
    { x: 1599652800000, y: 57, g: 'creation' },
    { x: 1599655500000, y: 56, g: 'creation' },
    { x: 1599658200000, y: 53, g: 'creation' },
    { x: 1599660900000, y: 51, g: 'creation' },
    { x: 1599663600000, y: 56, g: 'creation' },
    { x: 1599666300000, y: 31, g: 'creation' },
    { x: 1599579900000, y: 23, g: 'deletion' },
    { x: 1599582600000, y: 53, g: 'deletion' },
    { x: 1599585300000, y: 50, g: 'deletion' },
    { x: 1599588000000, y: 54, g: 'deletion' },
    { x: 1599590700000, y: 54, g: 'deletion' },
    { x: 1599593400000, y: 53, g: 'deletion' },
    { x: 1599596100000, y: 53, g: 'deletion' },
    { x: 1599598800000, y: 54, g: 'deletion' },
    { x: 1599601500000, y: 55, g: 'deletion' },
    { x: 1599604200000, y: 52, g: 'deletion' },
    { x: 1599606900000, y: 51, g: 'deletion' },
    { x: 1599609600000, y: 55, g: 'deletion' },
    { x: 1599612300000, y: 121, g: 'deletion' },
    { x: 1599615000000, y: 54, g: 'deletion' },
    { x: 1599617700000, y: 53, g: 'deletion' },
    { x: 1599620400000, y: 55, g: 'deletion' },
    { x: 1599623100000, y: 53, g: 'deletion' },
    { x: 1599625800000, y: 54, g: 'deletion' },
    { x: 1599628500000, y: 51, g: 'deletion' },
    { x: 1599631200000, y: 146, g: 'deletion' },
    { x: 1599633900000, y: 54, g: 'deletion' },
    { x: 1599636600000, y: 53, g: 'deletion' },
    { x: 1599639300000, y: 51, g: 'deletion' },
    { x: 1599642000000, y: 55, g: 'deletion' },
    { x: 1599644700000, y: 55, g: 'deletion' },
    { x: 1599647400000, y: 52, g: 'deletion' },
    { x: 1599650100000, y: 55, g: 'deletion' },
    { x: 1599652800000, y: 55, g: 'deletion' },
    { x: 1599655500000, y: 55, g: 'deletion' },
    { x: 1599658200000, y: 53, g: 'deletion' },
    { x: 1599660900000, y: 51, g: 'deletion' },
    { x: 1599663600000, y: 55, g: 'deletion' },
    { x: 1599666300000, y: 31, g: 'deletion' },
    { x: 1599579900000, y: 19, g: 'File Delete (rule: FileDelete)' },
    { x: 1599582600000, y: 46, g: 'File Delete (rule: FileDelete)' },
    { x: 1599585300000, y: 47, g: 'File Delete (rule: FileDelete)' },
    { x: 1599588000000, y: 47, g: 'File Delete (rule: FileDelete)' },
    { x: 1599590700000, y: 47, g: 'File Delete (rule: FileDelete)' },
    { x: 1599593400000, y: 45, g: 'File Delete (rule: FileDelete)' },
    { x: 1599596100000, y: 48, g: 'File Delete (rule: FileDelete)' },
    { x: 1599598800000, y: 46, g: 'File Delete (rule: FileDelete)' },
    { x: 1599601500000, y: 45, g: 'File Delete (rule: FileDelete)' },
    { x: 1599604200000, y: 47, g: 'File Delete (rule: FileDelete)' },
    { x: 1599606900000, y: 47, g: 'File Delete (rule: FileDelete)' },
    { x: 1599609600000, y: 60, g: 'File Delete (rule: FileDelete)' },
    { x: 1599612300000, y: 45, g: 'File Delete (rule: FileDelete)' },
    { x: 1599615000000, y: 46, g: 'File Delete (rule: FileDelete)' },
    { x: 1599617700000, y: 46, g: 'File Delete (rule: FileDelete)' },
    { x: 1599620400000, y: 47, g: 'File Delete (rule: FileDelete)' },
    { x: 1599623100000, y: 88, g: 'File Delete (rule: FileDelete)' },
    { x: 1599625800000, y: 53, g: 'File Delete (rule: FileDelete)' },
    { x: 1599628500000, y: 46, g: 'File Delete (rule: FileDelete)' },
    { x: 1599631200000, y: 49, g: 'File Delete (rule: FileDelete)' },
    { x: 1599633900000, y: 45, g: 'File Delete (rule: FileDelete)' },
    { x: 1599636600000, y: 48, g: 'File Delete (rule: FileDelete)' },
    { x: 1599639300000, y: 46, g: 'File Delete (rule: FileDelete)' },
    { x: 1599642000000, y: 46, g: 'File Delete (rule: FileDelete)' },
    { x: 1599644700000, y: 45, g: 'File Delete (rule: FileDelete)' },
    { x: 1599647400000, y: 47, g: 'File Delete (rule: FileDelete)' },
    { x: 1599650100000, y: 47, g: 'File Delete (rule: FileDelete)' },
    { x: 1599652800000, y: 45, g: 'File Delete (rule: FileDelete)' },
    { x: 1599655500000, y: 331, g: 'File Delete (rule: FileDelete)' },
    { x: 1599658200000, y: 45, g: 'File Delete (rule: FileDelete)' },
    { x: 1599660900000, y: 47, g: 'File Delete (rule: FileDelete)' },
    { x: 1599663600000, y: 47, g: 'File Delete (rule: FileDelete)' },
    { x: 1599666300000, y: 28, g: 'File Delete (rule: FileDelete)' },
    { x: 1599579900000, y: 3, g: 'session_id_change' },
    { x: 1599582600000, y: 9, g: 'session_id_change' },
    { x: 1599585300000, y: 7, g: 'session_id_change' },
    { x: 1599588000000, y: 10, g: 'session_id_change' },
    { x: 1599590700000, y: 7, g: 'session_id_change' },
    { x: 1599593400000, y: 10, g: 'session_id_change' },
    { x: 1599596100000, y: 63, g: 'session_id_change' },
    { x: 1599598800000, y: 7, g: 'session_id_change' },
    { x: 1599601500000, y: 45, g: 'session_id_change' },
    { x: 1599604200000, y: 4, g: 'session_id_change' },
    { x: 1599606900000, y: 5, g: 'session_id_change' },
    { x: 1599609600000, y: 6, g: 'session_id_change' },
    { x: 1599612300000, y: 6, g: 'session_id_change' },
    { x: 1599615000000, y: 55, g: 'session_id_change' },
    { x: 1599617700000, y: 43, g: 'session_id_change' },
    { x: 1599620400000, y: 8, g: 'session_id_change' },
    { x: 1599623100000, y: 9, g: 'session_id_change' },
    { x: 1599625800000, y: 7, g: 'session_id_change' },
    { x: 1599628500000, y: 21, g: 'session_id_change' },
    { x: 1599631200000, y: 26, g: 'session_id_change' },
    { x: 1599633900000, y: 17, g: 'session_id_change' },
    { x: 1599636600000, y: 34, g: 'session_id_change' },
    { x: 1599639300000, y: 41, g: 'session_id_change' },
    { x: 1599642000000, y: 18, g: 'session_id_change' },
    { x: 1599644700000, y: 4, g: 'session_id_change' },
    { x: 1599647400000, y: 11, g: 'session_id_change' },
    { x: 1599650100000, y: 9, g: 'session_id_change' },
    { x: 1599652800000, y: 7, g: 'session_id_change' },
    { x: 1599655500000, y: 12, g: 'session_id_change' },
    { x: 1599658200000, y: 16, g: 'session_id_change' },
    { x: 1599660900000, y: 7, g: 'session_id_change' },
    { x: 1599663600000, y: 99, g: 'session_id_change' },
    { x: 1599666300000, y: 21, g: 'session_id_change' },
  ],
};

export const mockDnsSearchStrategyResponse: IEsSearchResponse<unknown> = {
  isPartial: false,
  isRunning: false,
  rawResponse: {
    took: 36,
    timed_out: false,
    _shards: {
      total: 55,
      successful: 55,
      skipped: 38,
      failed: 0,
    },
    hits: {
      max_score: 0,
      hits: [],
      total: 0,
    },
    aggregations: {
      dns_count: {
        value: 3,
      },
      dns_name_query_count: {
        doc_count_error_upper_bound: 0,
        sum_other_doc_count: 0,
        buckets: [
          {
            key: 'google.com',
            doc_count: 1,
            unique_domains: {
              value: 1,
            },
            dns_question_name: {
              buckets: [
                {
                  key_as_string: '2020-11-12T01:13:31.395Z',
                  key: 1605143611395,
                  doc_count: 0,
                },
                {
                  key_as_string: '2020-11-12T01:21:48.492Z',
                  key: 1605144108492,
                  doc_count: 0,
                },
                {
                  key_as_string: '2020-11-12T01:30:05.589Z',
                  key: 1605144605589,
                  doc_count: 0,
                },
                {
                  key_as_string: '2020-11-12T01:38:22.686Z',
                  key: 1605145102686,
                  doc_count: 0,
                },
                {
                  key_as_string: '2020-11-12T01:46:39.783Z',
                  key: 1605145599783,
                  doc_count: 0,
                },
                {
                  key_as_string: '2020-11-12T01:54:56.880Z',
                  key: 1605146096880,
                  doc_count: 0,
                },
                {
                  key_as_string: '2020-11-12T02:03:13.977Z',
                  key: 1605146593977,
                  doc_count: 0,
                },
                {
                  key_as_string: '2020-11-12T02:11:31.074Z',
                  key: 1605147091074,
                  doc_count: 0,
                },
                {
                  key_as_string: '2020-11-12T02:19:48.171Z',
                  key: 1605147588171,
                  doc_count: 0,
                },
                {
                  key_as_string: '2020-11-12T02:28:05.268Z',
                  key: 1605148085268,
                  doc_count: 0,
                },
                {
                  key_as_string: '2020-11-12T02:36:22.365Z',
                  key: 1605148582365,
                  doc_count: 0,
                },
                {
                  key_as_string: '2020-11-12T02:44:39.462Z',
                  key: 1605149079462,
                  doc_count: 0,
                },
                {
                  key_as_string: '2020-11-12T02:52:56.559Z',
                  key: 1605149576559,
                  doc_count: 0,
                },
                {
                  key_as_string: '2020-11-12T03:01:13.656Z',
                  key: 1605150073656,
                  doc_count: 0,
                },
                {
                  key_as_string: '2020-11-12T03:09:30.753Z',
                  key: 1605150570753,
                  doc_count: 0,
                },
                {
                  key_as_string: '2020-11-12T03:17:47.850Z',
                  key: 1605151067850,
                  doc_count: 0,
                },
                {
                  key_as_string: '2020-11-12T03:26:04.947Z',
                  key: 1605151564947,
                  doc_count: 0,
                },
                {
                  key_as_string: '2020-11-12T03:34:22.044Z',
                  key: 1605152062044,
                  doc_count: 0,
                },
                {
                  key_as_string: '2020-11-12T03:42:39.141Z',
                  key: 1605152559141,
                  doc_count: 0,
                },
                {
                  key_as_string: '2020-11-12T03:50:56.238Z',
                  key: 1605153056238,
                  doc_count: 1,
                },
                {
                  key_as_string: '2020-11-12T03:59:13.335Z',
                  key: 1605153553335,
                  doc_count: 0,
                },
                {
                  key_as_string: '2020-11-12T04:07:30.432Z',
                  key: 1605154050432,
                  doc_count: 0,
                },
                {
                  key_as_string: '2020-11-12T04:15:47.529Z',
                  key: 1605154547529,
                  doc_count: 0,
                },
                {
                  key_as_string: '2020-11-12T04:24:04.626Z',
                  key: 1605155044626,
                  doc_count: 0,
                },
                {
                  key_as_string: '2020-11-12T04:32:21.723Z',
                  key: 1605155541723,
                  doc_count: 0,
                },
                {
                  key_as_string: '2020-11-12T04:40:38.820Z',
                  key: 1605156038820,
                  doc_count: 0,
                },
                {
                  key_as_string: '2020-11-12T04:48:55.917Z',
                  key: 1605156535917,
                  doc_count: 0,
                },
                {
                  key_as_string: '2020-11-12T04:57:13.014Z',
                  key: 1605157033014,
                  doc_count: 0,
                },
                {
                  key_as_string: '2020-11-12T05:05:30.111Z',
                  key: 1605157530111,
                  doc_count: 0,
                },
                {
                  key_as_string: '2020-11-12T05:13:47.208Z',
                  key: 1605158027208,
                  doc_count: 0,
                },
                {
                  key_as_string: '2020-11-12T05:22:04.305Z',
                  key: 1605158524305,
                  doc_count: 0,
                },
                {
                  key_as_string: '2020-11-12T05:30:21.402Z',
                  key: 1605159021402,
                  doc_count: 0,
                },
                {
                  key_as_string: '2020-11-12T05:38:38.499Z',
                  key: 1605159518499,
                  doc_count: 0,
                },
              ],
            },
            dns_bytes_in: {
              value: 0,
            },
            dns_bytes_out: {
              value: 0,
            },
          },
          {
            key: 'google.internal',
            doc_count: 1,
            unique_domains: {
              value: 1,
            },
            dns_question_name: {
              buckets: [
                {
                  key_as_string: '2020-11-12T01:13:31.395Z',
                  key: 1605143611395,
                  doc_count: 0,
                },
                {
                  key_as_string: '2020-11-12T01:21:48.492Z',
                  key: 1605144108492,
                  doc_count: 0,
                },
                {
                  key_as_string: '2020-11-12T01:30:05.589Z',
                  key: 1605144605589,
                  doc_count: 0,
                },
                {
                  key_as_string: '2020-11-12T01:38:22.686Z',
                  key: 1605145102686,
                  doc_count: 0,
                },
                {
                  key_as_string: '2020-11-12T01:46:39.783Z',
                  key: 1605145599783,
                  doc_count: 0,
                },
                {
                  key_as_string: '2020-11-12T01:54:56.880Z',
                  key: 1605146096880,
                  doc_count: 0,
                },
                {
                  key_as_string: '2020-11-12T02:03:13.977Z',
                  key: 1605146593977,
                  doc_count: 0,
                },
                {
                  key_as_string: '2020-11-12T02:11:31.074Z',
                  key: 1605147091074,
                  doc_count: 0,
                },
                {
                  key_as_string: '2020-11-12T02:19:48.171Z',
                  key: 1605147588171,
                  doc_count: 0,
                },
                {
                  key_as_string: '2020-11-12T02:28:05.268Z',
                  key: 1605148085268,
                  doc_count: 0,
                },
                {
                  key_as_string: '2020-11-12T02:36:22.365Z',
                  key: 1605148582365,
                  doc_count: 0,
                },
                {
                  key_as_string: '2020-11-12T02:44:39.462Z',
                  key: 1605149079462,
                  doc_count: 0,
                },
                {
                  key_as_string: '2020-11-12T02:52:56.559Z',
                  key: 1605149576559,
                  doc_count: 0,
                },
                {
                  key_as_string: '2020-11-12T03:01:13.656Z',
                  key: 1605150073656,
                  doc_count: 0,
                },
                {
                  key_as_string: '2020-11-12T03:09:30.753Z',
                  key: 1605150570753,
                  doc_count: 0,
                },
                {
                  key_as_string: '2020-11-12T03:17:47.850Z',
                  key: 1605151067850,
                  doc_count: 0,
                },
                {
                  key_as_string: '2020-11-12T03:26:04.947Z',
                  key: 1605151564947,
                  doc_count: 0,
                },
                {
                  key_as_string: '2020-11-12T03:34:22.044Z',
                  key: 1605152062044,
                  doc_count: 0,
                },
                {
                  key_as_string: '2020-11-12T03:42:39.141Z',
                  key: 1605152559141,
                  doc_count: 0,
                },
                {
                  key_as_string: '2020-11-12T03:50:56.238Z',
                  key: 1605153056238,
                  doc_count: 1,
                },
                {
                  key_as_string: '2020-11-12T03:59:13.335Z',
                  key: 1605153553335,
                  doc_count: 0,
                },
                {
                  key_as_string: '2020-11-12T04:07:30.432Z',
                  key: 1605154050432,
                  doc_count: 0,
                },
                {
                  key_as_string: '2020-11-12T04:15:47.529Z',
                  key: 1605154547529,
                  doc_count: 0,
                },
                {
                  key_as_string: '2020-11-12T04:24:04.626Z',
                  key: 1605155044626,
                  doc_count: 0,
                },
                {
                  key_as_string: '2020-11-12T04:32:21.723Z',
                  key: 1605155541723,
                  doc_count: 0,
                },
                {
                  key_as_string: '2020-11-12T04:40:38.820Z',
                  key: 1605156038820,
                  doc_count: 0,
                },
                {
                  key_as_string: '2020-11-12T04:48:55.917Z',
                  key: 1605156535917,
                  doc_count: 0,
                },
                {
                  key_as_string: '2020-11-12T04:57:13.014Z',
                  key: 1605157033014,
                  doc_count: 0,
                },
                {
                  key_as_string: '2020-11-12T05:05:30.111Z',
                  key: 1605157530111,
                  doc_count: 0,
                },
                {
                  key_as_string: '2020-11-12T05:13:47.208Z',
                  key: 1605158027208,
                  doc_count: 0,
                },
                {
                  key_as_string: '2020-11-12T05:22:04.305Z',
                  key: 1605158524305,
                  doc_count: 0,
                },
                {
                  key_as_string: '2020-11-12T05:30:21.402Z',
                  key: 1605159021402,
                  doc_count: 0,
                },
                {
                  key_as_string: '2020-11-12T05:38:38.499Z',
                  key: 1605159518499,
                  doc_count: 0,
                },
              ],
            },
            dns_bytes_in: {
              value: 0,
            },
            dns_bytes_out: {
              value: 0,
            },
          },
          {
            key: 'windows.net',
            doc_count: 1,
            unique_domains: {
              value: 1,
            },
            dns_question_name: {
              buckets: [
                {
                  key_as_string: '2020-11-12T01:13:31.395Z',
                  key: 1605143611395,
                  doc_count: 0,
                },
                {
                  key_as_string: '2020-11-12T01:21:48.492Z',
                  key: 1605144108492,
                  doc_count: 0,
                },
                {
                  key_as_string: '2020-11-12T01:30:05.589Z',
                  key: 1605144605589,
                  doc_count: 0,
                },
                {
                  key_as_string: '2020-11-12T01:38:22.686Z',
                  key: 1605145102686,
                  doc_count: 0,
                },
                {
                  key_as_string: '2020-11-12T01:46:39.783Z',
                  key: 1605145599783,
                  doc_count: 0,
                },
                {
                  key_as_string: '2020-11-12T01:54:56.880Z',
                  key: 1605146096880,
                  doc_count: 0,
                },
                {
                  key_as_string: '2020-11-12T02:03:13.977Z',
                  key: 1605146593977,
                  doc_count: 0,
                },
                {
                  key_as_string: '2020-11-12T02:11:31.074Z',
                  key: 1605147091074,
                  doc_count: 0,
                },
                {
                  key_as_string: '2020-11-12T02:19:48.171Z',
                  key: 1605147588171,
                  doc_count: 0,
                },
                {
                  key_as_string: '2020-11-12T02:28:05.268Z',
                  key: 1605148085268,
                  doc_count: 0,
                },
                {
                  key_as_string: '2020-11-12T02:36:22.365Z',
                  key: 1605148582365,
                  doc_count: 0,
                },
                {
                  key_as_string: '2020-11-12T02:44:39.462Z',
                  key: 1605149079462,
                  doc_count: 0,
                },
                {
                  key_as_string: '2020-11-12T02:52:56.559Z',
                  key: 1605149576559,
                  doc_count: 0,
                },
                {
                  key_as_string: '2020-11-12T03:01:13.656Z',
                  key: 1605150073656,
                  doc_count: 1,
                },
                {
                  key_as_string: '2020-11-12T03:09:30.753Z',
                  key: 1605150570753,
                  doc_count: 0,
                },
                {
                  key_as_string: '2020-11-12T03:17:47.850Z',
                  key: 1605151067850,
                  doc_count: 0,
                },
                {
                  key_as_string: '2020-11-12T03:26:04.947Z',
                  key: 1605151564947,
                  doc_count: 0,
                },
                {
                  key_as_string: '2020-11-12T03:34:22.044Z',
                  key: 1605152062044,
                  doc_count: 0,
                },
                {
                  key_as_string: '2020-11-12T03:42:39.141Z',
                  key: 1605152559141,
                  doc_count: 0,
                },
                {
                  key_as_string: '2020-11-12T03:50:56.238Z',
                  key: 1605153056238,
                  doc_count: 0,
                },
                {
                  key_as_string: '2020-11-12T03:59:13.335Z',
                  key: 1605153553335,
                  doc_count: 0,
                },
                {
                  key_as_string: '2020-11-12T04:07:30.432Z',
                  key: 1605154050432,
                  doc_count: 0,
                },
                {
                  key_as_string: '2020-11-12T04:15:47.529Z',
                  key: 1605154547529,
                  doc_count: 0,
                },
                {
                  key_as_string: '2020-11-12T04:24:04.626Z',
                  key: 1605155044626,
                  doc_count: 0,
                },
                {
                  key_as_string: '2020-11-12T04:32:21.723Z',
                  key: 1605155541723,
                  doc_count: 0,
                },
                {
                  key_as_string: '2020-11-12T04:40:38.820Z',
                  key: 1605156038820,
                  doc_count: 0,
                },
                {
                  key_as_string: '2020-11-12T04:48:55.917Z',
                  key: 1605156535917,
                  doc_count: 0,
                },
                {
                  key_as_string: '2020-11-12T04:57:13.014Z',
                  key: 1605157033014,
                  doc_count: 0,
                },
                {
                  key_as_string: '2020-11-12T05:05:30.111Z',
                  key: 1605157530111,
                  doc_count: 0,
                },
                {
                  key_as_string: '2020-11-12T05:13:47.208Z',
                  key: 1605158027208,
                  doc_count: 0,
                },
                {
                  key_as_string: '2020-11-12T05:22:04.305Z',
                  key: 1605158524305,
                  doc_count: 0,
                },
                {
                  key_as_string: '2020-11-12T05:30:21.402Z',
                  key: 1605159021402,
                  doc_count: 0,
                },
                {
                  key_as_string: '2020-11-12T05:38:38.499Z',
                  key: 1605159518499,
                  doc_count: 0,
                },
              ],
            },
            dns_bytes_in: {
              value: 0,
            },
            dns_bytes_out: {
              value: 0,
            },
          },
        ],
      },
    },
  },
  total: 21,
  loaded: 21,
};

export const formattedDnsSearchStrategyResponse: MatrixHistogramStrategyResponse = {
  ...mockDnsSearchStrategyResponse,
  inspect: {
    dsl: [
      JSON.stringify(
        {
          allow_no_indices: true,
          index: [
            'apm-*-transaction*',
            'traces-apm*',
            'auditbeat-*',
            'endgame-*',
            'filebeat-*',
            'logs-*',
            'packetbeat-*',
            'winlogbeat-*',
          ],
          ignore_unavailable: true,
          body: {
            aggregations: {
              dns_count: { cardinality: { field: 'dns.question.registered_domain' } },
              dns_name_query_count: {
                terms: {
                  field: 'dns.question.registered_domain',
                  order: { unique_domains: 'desc' },
                  size: 10,
                },
                aggs: {
                  unique_domains: { cardinality: { field: 'dns.question.name' } },
                  dns_question_name: {
                    date_histogram: {
                      field: '@timestamp',
                      fixed_interval: '2700000ms',
                      min_doc_count: 0,
                      extended_bounds: { min: 1599579675528, max: 1599666075529 },
                    },
                  },
                },
              },
            },
            query: {
              bool: {
                filter: [
                  { bool: { must: [], filter: [{ match_all: {} }], should: [], must_not: [] } },
                  {
                    range: {
                      '@timestamp': {
                        gte: '2020-09-08T15:41:15.528Z',
                        lte: '2020-09-09T15:41:15.529Z',
                        format: 'strict_date_optional_time',
                      },
                    },
                  },
                ],
                must_not: [{ term: { 'dns.question.type': { value: 'PTR' } } }],
              },
            },
          },
          size: 0,
          track_total_hits: false,
        },
        null,
        2
      ),
    ],
  },
  matrixHistogramData: [
    { x: 1605143611395, y: 0, g: 'google.com' },
    { x: 1605144108492, y: 0, g: 'google.com' },
    { x: 1605144605589, y: 0, g: 'google.com' },
    { x: 1605145102686, y: 0, g: 'google.com' },
    { x: 1605145599783, y: 0, g: 'google.com' },
    { x: 1605146096880, y: 0, g: 'google.com' },
    { x: 1605146593977, y: 0, g: 'google.com' },
    { x: 1605147091074, y: 0, g: 'google.com' },
    { x: 1605147588171, y: 0, g: 'google.com' },
    { x: 1605148085268, y: 0, g: 'google.com' },
    { x: 1605148582365, y: 0, g: 'google.com' },
    { x: 1605149079462, y: 0, g: 'google.com' },
    { x: 1605149576559, y: 0, g: 'google.com' },
    { x: 1605150073656, y: 0, g: 'google.com' },
    { x: 1605150570753, y: 0, g: 'google.com' },
    { x: 1605151067850, y: 0, g: 'google.com' },
    { x: 1605151564947, y: 0, g: 'google.com' },
    { x: 1605152062044, y: 0, g: 'google.com' },
    { x: 1605152559141, y: 0, g: 'google.com' },
    { x: 1605153056238, y: 1, g: 'google.com' },
    { x: 1605153553335, y: 0, g: 'google.com' },
    { x: 1605154050432, y: 0, g: 'google.com' },
    { x: 1605154547529, y: 0, g: 'google.com' },
    { x: 1605155044626, y: 0, g: 'google.com' },
    { x: 1605155541723, y: 0, g: 'google.com' },
    { x: 1605156038820, y: 0, g: 'google.com' },
    { x: 1605156535917, y: 0, g: 'google.com' },
    { x: 1605157033014, y: 0, g: 'google.com' },
    { x: 1605157530111, y: 0, g: 'google.com' },
    { x: 1605158027208, y: 0, g: 'google.com' },
    { x: 1605158524305, y: 0, g: 'google.com' },
    { x: 1605159021402, y: 0, g: 'google.com' },
    { x: 1605159518499, y: 0, g: 'google.com' },
    { x: 1605143611395, y: 0, g: 'google.internal' },
    { x: 1605144108492, y: 0, g: 'google.internal' },
    { x: 1605144605589, y: 0, g: 'google.internal' },
    { x: 1605145102686, y: 0, g: 'google.internal' },
    { x: 1605145599783, y: 0, g: 'google.internal' },
    { x: 1605146096880, y: 0, g: 'google.internal' },
    { x: 1605146593977, y: 0, g: 'google.internal' },
    { x: 1605147091074, y: 0, g: 'google.internal' },
    { x: 1605147588171, y: 0, g: 'google.internal' },
    { x: 1605148085268, y: 0, g: 'google.internal' },
    { x: 1605148582365, y: 0, g: 'google.internal' },
    { x: 1605149079462, y: 0, g: 'google.internal' },
    { x: 1605149576559, y: 0, g: 'google.internal' },
    { x: 1605150073656, y: 0, g: 'google.internal' },
    { x: 1605150570753, y: 0, g: 'google.internal' },
    { x: 1605151067850, y: 0, g: 'google.internal' },
    { x: 1605151564947, y: 0, g: 'google.internal' },
    { x: 1605152062044, y: 0, g: 'google.internal' },
    { x: 1605152559141, y: 0, g: 'google.internal' },
    { x: 1605153056238, y: 1, g: 'google.internal' },
    { x: 1605153553335, y: 0, g: 'google.internal' },
    { x: 1605154050432, y: 0, g: 'google.internal' },
    { x: 1605154547529, y: 0, g: 'google.internal' },
    { x: 1605155044626, y: 0, g: 'google.internal' },
    { x: 1605155541723, y: 0, g: 'google.internal' },
    { x: 1605156038820, y: 0, g: 'google.internal' },
    { x: 1605156535917, y: 0, g: 'google.internal' },
    { x: 1605157033014, y: 0, g: 'google.internal' },
    { x: 1605157530111, y: 0, g: 'google.internal' },
    { x: 1605158027208, y: 0, g: 'google.internal' },
    { x: 1605158524305, y: 0, g: 'google.internal' },
    { x: 1605159021402, y: 0, g: 'google.internal' },
    { x: 1605159518499, y: 0, g: 'google.internal' },
    { x: 1605143611395, y: 0, g: 'windows.net' },
    { x: 1605144108492, y: 0, g: 'windows.net' },
    { x: 1605144605589, y: 0, g: 'windows.net' },
    { x: 1605145102686, y: 0, g: 'windows.net' },
    { x: 1605145599783, y: 0, g: 'windows.net' },
    { x: 1605146096880, y: 0, g: 'windows.net' },
    { x: 1605146593977, y: 0, g: 'windows.net' },
    { x: 1605147091074, y: 0, g: 'windows.net' },
    { x: 1605147588171, y: 0, g: 'windows.net' },
    { x: 1605148085268, y: 0, g: 'windows.net' },
    { x: 1605148582365, y: 0, g: 'windows.net' },
    { x: 1605149079462, y: 0, g: 'windows.net' },
    { x: 1605149576559, y: 0, g: 'windows.net' },
    { x: 1605150073656, y: 1, g: 'windows.net' },
    { x: 1605150570753, y: 0, g: 'windows.net' },
    { x: 1605151067850, y: 0, g: 'windows.net' },
    { x: 1605151564947, y: 0, g: 'windows.net' },
    { x: 1605152062044, y: 0, g: 'windows.net' },
    { x: 1605152559141, y: 0, g: 'windows.net' },
    { x: 1605153056238, y: 0, g: 'windows.net' },
    { x: 1605153553335, y: 0, g: 'windows.net' },
    { x: 1605154050432, y: 0, g: 'windows.net' },
    { x: 1605154547529, y: 0, g: 'windows.net' },
    { x: 1605155044626, y: 0, g: 'windows.net' },
    { x: 1605155541723, y: 0, g: 'windows.net' },
    { x: 1605156038820, y: 0, g: 'windows.net' },
    { x: 1605156535917, y: 0, g: 'windows.net' },
    { x: 1605157033014, y: 0, g: 'windows.net' },
    { x: 1605157530111, y: 0, g: 'windows.net' },
    { x: 1605158027208, y: 0, g: 'windows.net' },
    { x: 1605158524305, y: 0, g: 'windows.net' },
    { x: 1605159021402, y: 0, g: 'windows.net' },
    { x: 1605159518499, y: 0, g: 'windows.net' },
  ],
  totalCount: 0,
};

export const formattedPreviewStrategyResponse = {
  ...mockAlertsSearchStrategyResponse,
  inspect: {
    dsl: [
      JSON.stringify(
        {
          index: ['.siem-preview-signals-default'],
          allow_no_indices: true,
          ignore_unavailable: true,
          track_total_hits: true,
          body: {
            aggregations: {
              preview: {
                terms: {
                  field: 'event.category',
                  missing: 'All others',
                  order: { _count: 'desc' },
                  size: 10,
                },
                aggs: {
                  preview: {
                    date_histogram: {
                      field: 'signal.original_time',
                      fixed_interval: '2700000ms',
                      min_doc_count: 0,
                      extended_bounds: { min: 1599574984482, max: 1599661384482 },
                    },
                  },
                },
              },
            },
            query: {
              bool: {
                filter: [
                  {
                    bool: {
                      must: [],
                      filter: [
                        { match_all: {} },
                        {
                          bool: {
                            filter: [
                              {
                                bool: {
                                  should: [{ match: { 'signal.rule.id': 'test-preview-id' } }],
                                  minimum_should_match: 1,
                                },
                              },
                            ],
                          },
                        },
                      ],
                      should: [],
                      must_not: [],
                    },
                  },
                  {
                    range: {
                      'signal.original_time': {
                        gte: '2020-09-08T14:23:04.482Z',
                        lte: '2020-09-09T14:23:04.482Z',
                        format: 'strict_date_optional_time',
                      },
                    },
                  },
                ],
              },
            },
            size: 0,
          },
        },
        null,
        2
      ),
    ],
  },
  matrixHistogramData: [],
  totalCount: 0,
};
